@@ -2,7 +2,6 @@ from dipy.align.transforms import regtransforms, Transform
 import numpy as np
 from numpy.testing import (assert_array_equal,
                            assert_array_almost_equal,
-                           assert_almost_equal,
                            assert_equal,
                            assert_raises)
 
@@ -17,7 +16,11 @@ def test_number_of_parameters():
                        ('SCALING', 2): 1,
                        ('SCALING', 3): 1,
                        ('AFFINE', 2): 6,
-                       ('AFFINE', 3): 12}
+                       ('AFFINE', 3): 12,
+                       ('RIGIDSCALING', 2): 5,
+                       ('RIGIDSCALING', 3): 9,
+                       ('RIGIDISOSCALING', 2): 4,
+                       ('RIGIDISOSCALING', 3): 7}
 
     for ttype, transform in regtransforms.items():
         assert_equal(
@@ -55,7 +58,7 @@ def test_param_to_matrix_2d():
     actual = transform.param_to_matrix(theta)
     assert_array_almost_equal(actual, expected)
 
-    # Test rigid matrix 2D
+    # Test scaling matrix 2D
     transform = regtransforms[('SCALING', 2)]
     factor = rng.uniform()
     theta = np.array([factor])
@@ -63,6 +66,30 @@ def test_param_to_matrix_2d():
     actual = transform.param_to_matrix(theta)
     assert_array_almost_equal(actual, expected)
 
+    # Test rigid isoscaling matrix 2D
+    transform = regtransforms[('RIGIDISOSCALING', 2)]
+    angle, dx, dy, factor = rng.uniform(size=(4,))
+    theta = np.array([angle, dx, dy, factor])
+    ct = np.cos(angle)
+    st = np.sin(angle)
+    expected = np.array([[ct*factor, -st*factor, dx],
+                         [st*factor, ct*factor, dy],
+                         [0, 0, 1]])
+    actual = transform.param_to_matrix(theta)
+    assert_array_almost_equal(actual, expected)
+
+    # Test rigid scaling matrix 2D
+    transform = regtransforms[('RIGIDSCALING', 2)]
+    angle, dx, dy, sx, sy = rng.uniform(size=(5,))
+    theta = np.array([angle, dx, dy, sx, sy])
+    ct = np.cos(angle)
+    st = np.sin(angle)
+    expected = np.array([[ct*sx, -st*sx, dx],
+                         [st*sy, ct*sy, dy],
+                         [0, 0, 1]])
+    actual = transform.param_to_matrix(theta)
+    assert_array_almost_equal(actual, expected)
+
     # Test affine 2D
     transform = regtransforms[('AFFINE', 2)]
     theta = rng.uniform(size=(6,))
@@ -75,7 +102,6 @@ def test_param_to_matrix_2d():
     # Verify that ValueError is raised if incorrect number of parameters
     for transform in regtransforms.values():
         n = transform.get_number_of_parameters()
-
         # Set incorrect number of parameters
         theta = np.zeros(n + 1, dtype=np.float64)
         assert_raises(ValueError, transform.param_to_matrix, theta)
@@ -94,27 +120,31 @@ def test_param_to_matrix_3d():
     actual = transform.param_to_matrix(theta)
     assert_array_equal(actual, expected)
 
+    # Create helpful rotation matrix function
+    def get_rotation_matrix(alpha, beta, gamma):
+        ca = np.cos(alpha)
+        sa = np.sin(alpha)
+        cb = np.cos(beta)
+        sb = np.sin(beta)
+        cc = np.cos(gamma)
+        sc = np.sin(gamma)
+
+        X = np.array([[1, 0, 0],
+                      [0, ca, -sa],
+                      [0, sa, ca]])
+        Y = np.array([[cb, 0, sb],
+                      [0, 1, 0],
+                      [-sb, 0, cb]])
+        Z = np.array([[cc, -sc, 0],
+                      [sc, cc, 0],
+                      [0, 0, 1]])
+
+        return Z.dot(X.dot(Y))  # Apply in order: Y, X, Z (Y goes to the right)
+
     # Test rotation matrix 3D
     transform = regtransforms[('ROTATION', 3)]
     theta = rng.uniform(size=(3,))
-    ca = np.cos(theta[0])
-    sa = np.sin(theta[0])
-    cb = np.cos(theta[1])
-    sb = np.sin(theta[1])
-    cc = np.cos(theta[2])
-    sc = np.sin(theta[2])
-
-    X = np.array([[1, 0, 0],
-                  [0, ca, -sa],
-                  [0, sa, ca]])
-    Y = np.array([[cb, 0, sb],
-                  [0, 1, 0],
-                  [-sb, 0, cb]])
-    Z = np.array([[cc, -sc, 0],
-                  [sc, cc, 0],
-                  [0, 0, 1]])
-
-    R = Z.dot(X.dot(Y))  # Apply in order: Y, X, Z (Y goes to the right)
+    R = get_rotation_matrix(theta[0], theta[1], theta[2])
     expected = np.eye(4)
     expected[:3, :3] = R[:3, :3]
     actual = transform.param_to_matrix(theta)
@@ -123,30 +153,36 @@ def test_param_to_matrix_3d():
     # Test rigid matrix 3D
     transform = regtransforms[('RIGID', 3)]
     theta = rng.uniform(size=(6,))
-    ca = np.cos(theta[0])
-    sa = np.sin(theta[0])
-    cb = np.cos(theta[1])
-    sb = np.sin(theta[1])
-    cc = np.cos(theta[2])
-    sc = np.sin(theta[2])
-
-    X = np.array([[1, 0, 0],
-                  [0, ca, -sa],
-                  [0, sa, ca]])
-    Y = np.array([[cb, 0, sb],
-                  [0, 1, 0],
-                  [-sb, 0, cb]])
-    Z = np.array([[cc, -sc, 0],
-                  [sc, cc, 0],
-                  [0, 0, 1]])
-
-    R = Z.dot(X.dot(Y))  # Apply in order: Y, X, Z (Y goes to the right)
+    R = get_rotation_matrix(theta[0], theta[1], theta[2])
     expected = np.eye(4)
     expected[:3, :3] = R[:3, :3]
     expected[:3, 3] = theta[3:6]
     actual = transform.param_to_matrix(theta)
     assert_array_almost_equal(actual, expected)
 
+    # Test rigid isoscaling matrix 3D
+    transform = regtransforms[('RIGIDISOSCALING', 3)]
+    theta = rng.uniform(size=(7,))
+    R = get_rotation_matrix(theta[0], theta[1], theta[2])
+    expected = np.eye(4)
+    expected[:3, :3] = R[:3, :3] * theta[6]
+    expected[:3, 3] = theta[3:6]
+    actual = transform.param_to_matrix(theta)
+    assert_array_almost_equal(actual, expected)
+
+    # Test rigid scaling matrix 3D
+    transform = regtransforms[('RIGIDSCALING', 3)]
+    theta = rng.uniform(size=(9,))
+    R = get_rotation_matrix(theta[0], theta[1], theta[2])
+    expected = np.eye(4)
+    R[0, :3] *= theta[6]
+    R[1, :3] *= theta[7]
+    R[2, :3] *= theta[8]
+    expected[:3, :3] = R[:3, :3]
+    expected[:3, 3] = theta[3:6]
+    actual = transform.param_to_matrix(theta)
+    assert_array_almost_equal(actual, expected)
+
     # Test scaling matrix 3D
     transform = regtransforms[('SCALING', 3)]
     factor = rng.uniform()
@@ -171,7 +207,6 @@ def test_param_to_matrix_3d():
     # Verify that ValueError is raised if incorrect number of parameters
     for transform in regtransforms.values():
         n = transform.get_number_of_parameters()
-
         # Set incorrect number of parameters
         theta = np.zeros(n + 1, dtype=np.float64)
         assert_raises(ValueError, transform.param_to_matrix, theta)
@@ -179,7 +214,6 @@ def test_param_to_matrix_3d():
 
 def test_identity_parameters():
     for transform in regtransforms.values():
-        n = transform.get_number_of_parameters()
         dim = transform.get_dim()
         theta = transform.get_identity_parameters()
 
@@ -222,7 +256,6 @@ def test_jacobian_functions():
     # length
     for transform in regtransforms.values():
         n = transform.get_number_of_parameters()
-
         # Wrong number of parameters
         theta = np.zeros(n + 1)
         x = np.zeros(dim)
@@ -233,9 +266,9 @@ def test_invalid_transform():
     # Note: users should not attempt to use the base class Transform:
     # they should get an instance of one of its derived classes from the
     # regtransforms dictionary (the base class is not contained there)
-    # If for some reason the user instanciates it and attempts to use it,
+    # If for some reason the user instantiates it and attempts to use it,
     # however, it will raise exceptions when attempting to retrieve its
-    # jacobian, identity parameters or its matrix representation. It will
+    # Jacobian, identity parameters or its matrix representation. It will
     # return -1 if queried about its dimension or number of parameters
     transform = Transform()
     theta = np.ndarray(3)
