@@ -1,10 +1,9 @@
-''' Utility functions for algebra etc '''
-from __future__ import division, print_function, absolute_import
+""" Utility functions for algebra etc """
 
+import itertools
 import math
 import numpy as np
 import numpy.linalg as npl
-from dipy.testing import setup_test
 
 # epsilon for testing whether a number is close to zero
 _EPS = np.finfo(float).eps * 4.0
@@ -27,7 +26,7 @@ _TUPLE2AXES = dict((v, k) for k, v in _AXES2TUPLE.items())
 
 
 def sphere2cart(r, theta, phi):
-    ''' Spherical to Cartesian coordinates
+    """ Spherical to Cartesian coordinates
 
     This is the standard physics convention where `theta` is the
     inclination (polar) angle, and `phi` is the azimuth angle.
@@ -90,7 +89,7 @@ def sphere2cart(r, theta, phi):
     name, because the Matlab function uses an unusual convention for the
     angles that we did not want to replicate.  The Matlab function is
     trivial to implement with the formulae given in the Matlab help.
-    '''
+    """
     sin_theta = np.sin(theta)
     x = r * np.cos(phi) * sin_theta
     y = r * np.sin(phi) * sin_theta
@@ -100,7 +99,7 @@ def sphere2cart(r, theta, phi):
 
 
 def cart2sphere(x, y, z):
-    r''' Return angles for Cartesian 3D coordinates `x`, `y`, and `z`
+    r""" Return angles for Cartesian 3D coordinates `x`, `y`, and `z`
 
     See doc for ``sphere2cart`` for angle conventions and derivation
     of the formulae.
@@ -124,7 +123,7 @@ def cart2sphere(x, y, z):
        inclination (polar) angle
     phi : array
        azimuth angle
-    '''
+    """
     r = np.sqrt(x * x + y * y + z * z)
     theta = np.arccos(np.divide(z, r, where=r > 0))
     theta = np.where(r > 0, theta, 0.)
@@ -146,7 +145,7 @@ def sph2latlon(theta, phi):
 
 
 def normalized_vector(vec, axis=-1):
-    ''' Return vector divided by its Euclidean (L2) norm
+    """ Return vector divided by its Euclidean (L2) norm
 
     See :term:`unit vector` and :term:`Euclidean norm`
 
@@ -171,12 +170,12 @@ def normalized_vector(vec, axis=-1):
     True
     >>> normalized_vector(vec).shape == (1, 3)
     True
-    '''
+    """
     return vec / vector_norm(vec, axis, keepdims=True)
 
 
 def vector_norm(vec, axis=-1, keepdims=False):
-    ''' Return vector Euclidean (L2) norm
+    """ Return vector Euclidean (L2) norm
 
     See :term:`unit vector` and :term:`Euclidean norm`
 
@@ -207,7 +206,7 @@ def vector_norm(vec, axis=-1, keepdims=False):
            [ 85.]])
     >>> vector_norm(vec, axis=0)
     array([  8.,  39.,  77.])
-    '''
+    """
     vec = np.asarray(vec)
     vec_norm = np.sqrt((vec * vec).sum(axis))
     if keepdims:
@@ -283,7 +282,7 @@ def rodrigues_axis_rotation(r, theta):
 
 
 def nearest_pos_semi_def(B):
-    ''' Least squares positive semi-definite tensor estimation
+    """ Least squares positive semi-definite tensor estimation
 
     Parameters
     ------------
@@ -310,7 +309,7 @@ def nearest_pos_semi_def(B):
            2006;1:2622-5. PubMed PMID: 17946125; PubMed Central PMCID:
            PMC2791793.
 
-    '''
+    """
     B = np.asarray(B)
     vals, vecs = npl.eigh(B)
     # indices of eigenvalues in descending order
@@ -399,7 +398,7 @@ def sphere_distance(pts1, pts2, radius=None, check_radius=True):
 
 
 def cart_distance(pts1, pts2):
-    ''' Cartesian distance between `pts1` and `pts2`
+    """ Cartesian distance between `pts1` and `pts2`
 
     If either of `pts1` or `pts2` is 2D, then we take the first
     dimension to index points, and the second indexes coordinate.  More
@@ -430,7 +429,7 @@ def cart_distance(pts1, pts2):
     ----------
     >>> cart_distance([0,0,0], [0,0,3])
     3.0
-    '''
+    """
     sqs = np.subtract(pts1, pts2) ** 2
     return np.sqrt(np.sum(sqs, axis=-1))
 
@@ -507,7 +506,7 @@ def lambert_equal_area_projection_polar(theta, phi):
 
 
 def lambert_equal_area_projection_cart(x, y, z):
-    r''' Lambert Equal Area Projection from cartesian vector to plane
+    r""" Lambert Equal Area Projection from cartesian vector to plane
 
     Return positions in $(y_1,y_2)$ plane corresponding to the
     directions of the vectors with cartesian coordinates xyz under the
@@ -535,7 +534,7 @@ def lambert_equal_area_projection_cart(x, y, z):
     ----------
     y : (N,2) array
        planar coordinates of points following mapping by Lambert's EAP.
-    '''
+    """
 
     (r, theta, phi) = cart2sphere(x, y, z)
     return lambert_equal_area_projection_polar(theta, phi)
@@ -778,7 +777,7 @@ def decompose_matrix(matrix):
 
 
 def circumradius(a, b, c):
-    ''' a, b and c are 3-dimensional vectors which are the vertices of a
+    """ a, b and c are 3-dimensional vectors which are the vertices of a
     triangle. The function returns the circumradius of the triangle, i.e
     the radius of the smallest circle that can contain the triangle. In
     the degenerate case when the 3 points are collinear it returns
@@ -793,7 +792,7 @@ def circumradius(a, b, c):
     -------
     circumradius : float
         the desired circumradius
-    '''
+    """
     x = a - c
     xx = np.linalg.norm(x) ** 2
     y = b - c
@@ -1026,3 +1025,62 @@ def dist_to_corner(affine):
     R = affine[0:3, 0:3]
     vox_dim = np.diag(np.linalg.cholesky(R.T.dot(R)))
     return np.sqrt(np.sum((vox_dim / 2) ** 2))
+
+
+def is_hemispherical(vecs):
+    """Test whether all points on a unit sphere lie in the same hemisphere.
+
+    Parameters
+    ----------
+    vecs : numpy.ndarray
+        2D numpy array with shape (N, 3) where N is the number of points.
+        All points must lie on the unit sphere.
+
+    Returns
+    -------
+    is_hemi : bool
+        If True, one can find a hemisphere that contains all the points.
+        If False, then the points do not lie in any hemisphere
+
+    pole : numpy.ndarray
+        If `is_hemi == True`, then pole is the "central" pole of the
+        input vectors. Otherwise, pole is the zero vector.
+
+    References
+    ----------
+    https://rstudio-pubs-static.s3.amazonaws.com/27121_a22e51b47c544980bad594d5e0bb2d04.html  # noqa
+    """
+    if vecs.shape[1] != 3:
+        raise ValueError("Input vectors must be 3D vectors")
+    if not np.allclose(1, np.linalg.norm(vecs, axis=1)):
+        raise ValueError("Input vectors must be unit vectors")
+
+    # Generate all pairwise cross products
+    v0, v1 = zip(*[p for p in itertools.permutations(vecs, 2)])
+    cross_prods = np.cross(v0, v1)
+
+    # Normalize them
+    cross_prods /= np.linalg.norm(cross_prods, axis=1)[:, np.newaxis]
+
+    # `cross_prods` now contains all candidate vertex points for "the polygon"
+    # in the reference. "The polygon" is a subset. Find which points belong to
+    # the polygon using a dot product test with each of the original vectors
+    angles = np.arccos(np.dot(cross_prods, vecs.transpose()))
+
+    # And test whether it is orthogonal or less
+    dot_prod_test = angles <= np.pi / 2.0
+
+    # If there is at least one point that is orthogonal or less to each
+    # input vector, then the points lie on some hemisphere
+    is_hemi = len(vecs) in np.sum(dot_prod_test.astype(int), axis=1)
+
+    if is_hemi:
+        vertices = cross_prods[
+            np.sum(dot_prod_test.astype(int), axis=1) == len(vecs)
+        ]
+
+        pole = np.mean(vertices, axis=0)
+        pole /= np.linalg.norm(pole)
+    else:
+        pole = np.array([0.0, 0.0, 0.0])
+    return is_hemi, pole
