@@ -1,5 +1,3 @@
-from __future__ import division, print_function, absolute_import
-
 import numpy as np
 from numpy.lib.stride_tricks import as_strided
 
@@ -42,5 +40,5 @@ def ndindex(shape):
             for ix in np.ndindex(*shape):
                 yield ix
         else:
-            for e in ndi:
+            for _ in ndi:
                 yield ndi.multi_index
