@@ -212,7 +212,7 @@ class Sphere(object):
         return unique_edges(self.faces)
 
     def subdivide(self, n=1):
-        """Subdivides each face of the sphere into four new faces.
+        r"""Subdivides each face of the sphere into four new faces.
 
         New vertices are created at a, b, and c. Then each face [x, y, z] is
         divided into faces [x, a, c], [y, a, b], [z, b, c], and [a, b, c].
@@ -518,7 +518,7 @@ def _equality_constraints(vects):
     return (vects ** 2).sum(1) - 1.0
 
 def _grad_equality_constraints(vects):
-    """Return normals to the surface constraint (which corresponds to
+    r"""Return normals to the surface constraint (which corresponds to
     the gradient of the implicit function).
 
     Parameters
