@@ -19,15 +19,15 @@ from dipy.core.geometry import (sphere2cart, cart2sphere,
                                 compose_matrix,
                                 decompose_matrix,
                                 perpendicular_directions,
-                                dist_to_corner)
-
-from nose.tools import (assert_false, assert_equal, assert_raises,
-                        assert_almost_equal)
+                                dist_to_corner,
+                                is_hemispherical)
 
 from numpy.testing import (assert_array_equal, assert_array_almost_equal,
+                           assert_equal, assert_raises, assert_almost_equal,
                            run_module_suite)
 
-from dipy.testing import sphere_points
+from dipy.testing.spherepoints import sphere_points
+from dipy.core.sphere_stats import random_uniform_on_sphere
 from itertools import permutations
 
 
@@ -48,30 +48,30 @@ def test_sphere_cart():
     # test arrays of points
     rs, thetas, phis = cart2sphere(*(sphere_points.T))
     xyz = sphere2cart(rs, thetas, phis)
-    yield assert_array_almost_equal, xyz, sphere_points.T
+    assert_array_almost_equal(xyz, sphere_points.T)
     # test radius estimation
     big_sph_pts = sphere_points * 10.4
     rs, thetas, phis = cart2sphere(*big_sph_pts.T)
-    yield assert_array_almost_equal, rs, 10.4
+    assert_array_almost_equal(rs, 10.4)
     xyz = sphere2cart(rs, thetas, phis)
-    yield assert_array_almost_equal, xyz, big_sph_pts.T, 6
+    assert_array_almost_equal(xyz, big_sph_pts.T, decimal=6)
     # test that result shapes match
     x, y, z = big_sph_pts.T
     r, theta, phi = cart2sphere(x[:1], y[:1], z)
-    yield assert_equal, r.shape, theta.shape
-    yield assert_equal, r.shape, phi.shape
+    assert_equal(r.shape, theta.shape)
+    assert_equal(r.shape, phi.shape)
     x, y, z = sphere2cart(r[:1], theta[:1], phi)
-    yield assert_equal, x.shape, y.shape
-    yield assert_equal, x.shape, z.shape
+    assert_equal(x.shape, y.shape)
+    assert_equal(x.shape, z.shape)
     # test a scalar point
     pt = sphere_points[3]
     r, theta, phi = cart2sphere(*pt)
     xyz = sphere2cart(r, theta, phi)
-    yield assert_array_almost_equal, xyz, pt
+    assert_array_almost_equal(xyz, pt)
 
     # Test full circle on x=1, y=1, z=1
     x, y, z = sphere2cart(*cart2sphere(1.0, 1.0, 1.0))
-    yield assert_array_almost_equal, (x, y, z), (1.0, 1.0, 1.0)
+    assert_array_almost_equal((x, y, z), (1.0, 1.0, 1.0))
 
 
 def test_invert_transform():
@@ -81,42 +81,42 @@ def test_invert_transform():
     x, y, z = sphere2cart(1, theta, phi)  # Let's assume they're all unit vecs
     r, new_theta, new_phi = cart2sphere(x, y, z)  # Transform back
 
-    yield assert_array_almost_equal, theta, new_theta
-    yield assert_array_almost_equal, phi, new_phi
+    assert_array_almost_equal(theta, new_theta)
+    assert_array_almost_equal(phi, new_phi)
 
 
 def test_nearest_pos_semi_def():
     B = np.diag(np.array([1, 2, 3]))
-    yield assert_array_almost_equal, B, nearest_pos_semi_def(B)
+    assert_array_almost_equal(B, nearest_pos_semi_def(B))
     B = np.diag(np.array([0, 2, 3]))
-    yield assert_array_almost_equal, B, nearest_pos_semi_def(B)
+    assert_array_almost_equal(B, nearest_pos_semi_def(B))
     B = np.diag(np.array([0, 0, 3]))
-    yield assert_array_almost_equal, B, nearest_pos_semi_def(B)
+    assert_array_almost_equal(B, nearest_pos_semi_def(B))
     B = np.diag(np.array([-1, 2, 3]))
     Bpsd = np.array([[0., 0., 0.], [0., 1.75, 0.], [0., 0., 2.75]])
-    yield assert_array_almost_equal, Bpsd, nearest_pos_semi_def(B)
+    assert_array_almost_equal(Bpsd, nearest_pos_semi_def(B))
     B = np.diag(np.array([-1, -2, 3]))
     Bpsd = np.array([[0., 0., 0.], [0., 0., 0.], [0., 0., 2.]])
-    yield assert_array_almost_equal, Bpsd, nearest_pos_semi_def(B)
+    assert_array_almost_equal(Bpsd, nearest_pos_semi_def(B))
     B = np.diag(np.array([-1.e-11, 0, 1000]))
     Bpsd = np.array([[0., 0., 0.], [0., 0., 0.], [0., 0., 1000.]])
-    yield assert_array_almost_equal, Bpsd, nearest_pos_semi_def(B)
+    assert_array_almost_equal(Bpsd, nearest_pos_semi_def(B))
     B = np.diag(np.array([-1, -2, -3]))
     Bpsd = np.array([[0., 0., 0.], [0., 0., 0.], [0., 0., 0.]])
-    yield assert_array_almost_equal, Bpsd, nearest_pos_semi_def(B)
+    assert_array_almost_equal(Bpsd, nearest_pos_semi_def(B))
 
 
 def test_cart_distance():
     a = [0, 1]
     b = [1, 0]
-    yield assert_array_almost_equal, cart_distance(a, b), np.sqrt(2)
-    yield assert_array_almost_equal, cart_distance([1, 0], [-1, 0]), 2
+    assert_array_almost_equal(cart_distance(a, b), np.sqrt(2))
+    assert_array_almost_equal(cart_distance([1, 0], [-1, 0]), 2)
     pts1 = [2, 1, 0]
     pts2 = [0, 1, -2]
-    yield assert_array_almost_equal, cart_distance(pts1, pts2), np.sqrt(8)
+    assert_array_almost_equal(cart_distance(pts1, pts2), np.sqrt(8))
     pts2 = [[0, 1, -2],
             [-2, 1, 0]]
-    yield assert_array_almost_equal, cart_distance(pts1, pts2), [np.sqrt(8), 4]
+    assert_array_almost_equal(cart_distance(pts1, pts2), [np.sqrt(8), 4])
 
 
 def test_sphere_distance():
@@ -138,44 +138,43 @@ def test_sphere_distance():
     cdists = np.r_[0, csums, csums[-2::-1]]
     # check approximation close to calculated
     sph_d = sphere_distance([0, radius], np.c_[x, y])
-    yield assert_array_almost_equal, cdists, sph_d
+    assert_array_almost_equal(cdists, sph_d)
     # Now check with passed radius
     sph_d = sphere_distance([0, radius], np.c_[x, y], radius=radius)
-    yield assert_array_almost_equal, cdists, sph_d
+    assert_array_almost_equal(cdists, sph_d)
     # Check points not on surface raises error when asked for
-    yield assert_raises, ValueError, sphere_distance, [1, 0], [0, 2]
+    assert_raises(ValueError, sphere_distance, [1, 0], [0, 2])
     # Not when check is disabled
     sphere_distance([1, 0], [0, 2], None, False)
     # Error when radii don't match passed radius
-    yield assert_raises, ValueError, sphere_distance, [1, 0], [0, 1], 2.0
+    assert_raises(ValueError, sphere_distance, [1, 0], [0, 1], 2.0)
 
 
 def test_vector_cosine():
     a = [0, 1]
     b = [1, 0]
-    yield assert_array_almost_equal, vector_cosine(a, b), 0
-    yield assert_array_almost_equal, vector_cosine([1, 0], [-1, 0]), -1
-    yield assert_array_almost_equal, vector_cosine([1, 0], [1, 1]), \
-        1/np.sqrt(2)
-    yield assert_array_almost_equal, vector_cosine([2, 0], [-4, 0]), -1
+    assert_array_almost_equal(vector_cosine(a, b), 0)
+    assert_array_almost_equal(vector_cosine([1, 0], [-1, 0]), -1)
+    assert_array_almost_equal(vector_cosine([1, 0], [1, 1]), 1 / np.sqrt(2))
+    assert_array_almost_equal(vector_cosine([2, 0], [-4, 0]), -1)
     pts1 = [2, 1, 0]
     pts2 = [-2, -1, 0]
-    yield assert_array_almost_equal, vector_cosine(pts1, pts2), -1
+    assert_array_almost_equal(vector_cosine(pts1, pts2), -1)
     pts2 = [[-2, -1, 0],
             [2, 1, 0]]
-    yield assert_array_almost_equal, vector_cosine(pts1, pts2), [-1, 1]
+    assert_array_almost_equal(vector_cosine(pts1, pts2), [-1, 1])
     # test relationship with correlation
     # not the same if non-zero vector mean
     a = np.random.uniform(size=(100,))
     b = np.random.uniform(size=(100,))
     cc = np.corrcoef(a, b)[0, 1]
     vcos = vector_cosine(a, b)
-    yield assert_false, np.allclose(cc, vcos)
+    assert not np.allclose(cc, vcos)
     # is the same if zero vector mean
     a_dm = a - np.mean(a)
     b_dm = b - np.mean(b)
     vcos = vector_cosine(a_dm, b_dm)
-    yield assert_array_almost_equal, cc, vcos
+    assert_array_almost_equal(cc, vcos)
 
 
 def test_lambert_equal_area_projection_polar():
@@ -184,9 +183,9 @@ def test_lambert_equal_area_projection_polar():
     phi = np.linspace(0, 2*np.pi, 10)
     # points sit on circle with co-latitude pi/3 (60 degrees)
     leap = lambert_equal_area_projection_polar(theta, phi)
-    yield \
-        assert_array_almost_equal, np.sqrt(np.sum(leap**2, axis=1)), \
-        np.array([1., 1., 1., 1., 1., 1., 1., 1., 1., 1.])
+    assert_array_almost_equal(np.sqrt(np.sum(leap**2, axis=1)),
+                              np.array([1., 1., 1., 1., 1.,
+                                        1., 1., 1., 1., 1.]))
     # points map onto the circle of radius 1
 
 
@@ -200,8 +199,8 @@ def test_lambert_equal_area_projection_cart():
 
     leap = lambert_equal_area_projection_polar(theta, phi)
     r2 = np.sqrt(2)
-    yield assert_array_almost_equal, np.sqrt(np.sum(leap**2, axis=1)), \
-        np.array([r2, r2, 0, r2, r2, 2])
+    assert_array_almost_equal(np.sqrt(np.sum(leap**2, axis=1)),
+                              np.array([r2, r2, 0, r2, r2, 2]))
     # x and y =+/-1 map onto circle of radius sqrt(2)
     # z=1 maps to origin, and z=-1 maps to (an arbitrary point on) the
     # outer circle of radius 2
@@ -209,9 +208,9 @@ def test_lambert_equal_area_projection_cart():
 
 def test_circumradius():
 
-    yield assert_array_almost_equal, np.sqrt(0.5), \
-        circumradius(np.array([0, 2, 0]), np.array([2, 0, 0]),
-                     np.array([0, 0, 0]))
+    assert_array_almost_equal(np.sqrt(0.5), circumradius(np.array([0, 2, 0]),
+                                                         np.array([2, 0, 0]),
+                                                         np.array([0, 0, 0])))
 
 
 def test_vec2vec_rotmat():
@@ -271,7 +270,7 @@ def test_perpendicular_directions():
     for vector_v in vectors_v:
         pd = perpendicular_directions(vector_v, num=num, half=False)
 
-        # see if length of pd is equal to the number of intendend samples
+        # see if length of pd is equal to the number of intended samples
         assert_equal(num, len(pd))
 
         # check if all directions are perpendicular to vector v
@@ -318,5 +317,24 @@ def test_dist_to_corner():
     assert_array_almost_equal(dist_to_corner(new_aff), pythagoras)
 
 
+def test_is_hemispherical():
+    # Smoke test the ValueError for non-3D vectors
+    assert_raises(ValueError, is_hemispherical, np.array(
+        [[1, 2, 3, 4], [5, 6, 7, 8]]
+    ))
+
+    # Test on hemispherical input
+    xyz = random_uniform_on_sphere(n=100, coords='xyz')
+    xyz = xyz[xyz[:, 2] > 0]
+    assert_equal(is_hemispherical(xyz)[0], True)
+
+    # Test on spherical input
+    xyz = random_uniform_on_sphere(n=100, coords='xyz')
+    assert_equal(is_hemispherical(xyz)[0], False)
+
+    # Smoke test the ValueError for non unit-vectors
+    assert_raises(ValueError, is_hemispherical, xyz * 2.0)
+
+
 if __name__ == '__main__':
     run_module_suite()
