@@ -1,4 +1,3 @@
-from __future__ import division, print_function
 
 import numpy as np
 
@@ -57,7 +56,7 @@ def piesno(data, N, alpha=0.01, l=100, itermax=100, eps=1e-5,
         reached if two subsequent estimates are smaller than eps.
 
     return_mask : bool
-        If True, return a mask identyfing all the pure noise voxel
+        If True, return a mask identifying all the pure noise voxel
         that were found.
 
     Returns
@@ -68,7 +67,7 @@ def piesno(data, N, alpha=0.01, l=100, itermax=100, eps=1e-5,
     mask : ndarray (optional)
         A boolean mask indicating the voxels identified as pure noise.
 
-    Note
+    Notes
     ------
     This function assumes two things : 1. The data has a noisy, non-masked
     background and 2. The data is a repetition of the same measurements
@@ -105,7 +104,7 @@ def piesno(data, N, alpha=0.01, l=100, itermax=100, eps=1e-5,
         q = 0.5
 
     # Initial estimation of sigma
-    initial_estimation = (np.percentile(data, q * 100) / 
+    initial_estimation = (np.percentile(data, q * 100) /
                           np.sqrt(2 * _inv_nchi_cdf(N, 1, q)))
 
     if data.ndim == 4:
@@ -114,7 +113,7 @@ def piesno(data, N, alpha=0.01, l=100, itermax=100, eps=1e-5,
         mask_noise = np.zeros(data.shape[:-1], dtype=np.bool)
 
         for idx in range(data.shape[-2]):
-            sigma[idx], mask_noise[..., idx] = _piesno_3D(data[..., idx, :], 
+            sigma[idx], mask_noise[..., idx] = _piesno_3D(data[..., idx, :],
                                                           N,
                                                           alpha=alpha,
                                                           l=l,
@@ -171,7 +170,7 @@ def _piesno_3D(data, N, alpha=0.01, l=100, itermax=100, eps=1e-5,
         Default: 1e-5.
 
     return_mask : bool (optional)
-        If True, return a mask identyfing all the pure noise voxel
+        If True, return a mask identifying all the pure noise voxel
         that were found. Default: False.
 
     initial_estimation : float (optional)
@@ -227,7 +226,7 @@ def _piesno_3D(data, N, alpha=0.01, l=100, itermax=100, eps=1e-5,
 
     phi = np.arange(1, l + 1) * m / l
     K = data.shape[-1]
-    sum_m2 = np.sum(data**2, axis=-1, dtype=np.float32)
+    sum_m2 = np.sum(data.astype(np.float32)**2, axis=2)
 
     sigma_prev = 0
     sigma = m
@@ -294,7 +293,7 @@ def estimate_sigma(arr, disable_background_masking=False, N=0):
     sigma : ndarray
         standard deviation of the noise, one estimation per volume.
 
-    Note
+    Notes
     -------
     This function is the same as manually taking the standard deviation of the
     background and gives one value for the whole 3D array.
@@ -306,8 +305,8 @@ def estimate_sigma(arr, disable_background_masking=False, N=0):
     profiles. Consider using :func:`piesno` to estimate sigma instead if visual
     inaccuracies are apparent in the denoised result.
 
-    Reference
-    -------
+    References
+    ----------
     .. [1] Koay, C. G., & Basser, P. J. (2006). Analytically exact correction
     scheme for signal extraction from noisy magnitude MR signals.
     Journal of Magnetic Resonance), 179(2), 317-22.
@@ -315,6 +314,7 @@ def estimate_sigma(arr, disable_background_masking=False, N=0):
     .. [2] Coupe, P., Yger, P., Prima, S., Hellier, P., Kervrann, C., Barillot,
     C., 2008. An optimized blockwise nonlocal means denoising filter for 3-D
     magnetic resonance images, IEEE Trans. Med. Imaging 27, 425-41.
+
     """
     k = np.zeros((3, 3, 3), dtype=np.int8)
 
