@@ -4,6 +4,7 @@ from numpy.testing import (run_module_suite,
                            assert_equal,
                            assert_array_almost_equal,
                            assert_raises)
+import pytest
 from dipy.denoise.nlmeans import nlmeans
 from dipy.denoise.denspeed import (add_padding_reflection, remove_padding)
 from dipy.utils.omp import cpu_count, have_openmp
@@ -89,7 +90,8 @@ def test_nlmeans_dtype():
     S0n = nlmeans(S0, sigma=np.ones((20, 20, 20)), mask=mask, rician=True)
     assert_equal(S0.dtype, S0n.dtype)
 
-@np.testing.dec.skipif(not have_openmp, 'OpenMP does not appear to be available')
+@pytest.mark.skipif(not have_openmp,
+                    reason='OpenMP does not appear to be available')
 def test_nlmeans_4d_3dsigma_and_threads():
     # Input is 4D data and 3D sigma
     data = np.ones((50, 50, 50, 5))
