@@ -1,12 +1,9 @@
-from __future__ import division, print_function, absolute_import
 
 from multiprocessing import cpu_count, Pool
 from itertools import repeat
 from os import path
 from warnings import warn
 
-from dipy.utils.six.moves import xrange
-
 from nibabel.tmpdirs import InTemporaryDirectory
 
 import numpy as np
@@ -19,7 +16,7 @@ from dipy.core.sphere import Sphere
 from dipy.data import default_sphere
 from dipy.core.ndindex import ndindex
 from dipy.reconst.shm import sh_to_sf_matrix
-from dipy.reconst.peak_direction_getter import PeaksAndMetricsDirectionGetter
+from dipy.reconst.eudx_direction_getter import EuDXDirectionGetter
 
 
 def peak_directions_nl(sphere_eval, relative_peak_threshold=.25,
@@ -66,7 +63,7 @@ def peak_directions_nl(sphere_eval, relative_peak_threshold=.25,
     num_seeds = len(seeds)
     theta = np.empty(num_seeds)
     phi = np.empty(num_seeds)
-    for i in xrange(num_seeds):
+    for i in range(num_seeds):
         peak = opt.fmin(_helper, seeds[i], xtol=xtol, disp=False)
         theta[i], phi[i] = peak
 
@@ -91,7 +88,7 @@ def peak_directions_nl(sphere_eval, relative_peak_threshold=.25,
 
 
 def peak_directions(odf, sphere, relative_peak_threshold=.5,
-                    min_separation_angle=25, minmax_norm=True):
+                    min_separation_angle=25):
     """Get the directions of odf peaks.
 
     Peaks are defined as points on the odf that are greater than at least one
@@ -208,7 +205,7 @@ def _pam_from_attrs(klass, sphere, peak_indices, peak_values, peak_dirs,
     return this_pam
 
 
-class PeaksAndMetrics(PeaksAndMetricsDirectionGetter):
+class PeaksAndMetrics(EuDXDirectionGetter):
     def __reduce__(self): return _pam_from_attrs, (self.__class__,
                                                    self.sphere,
                                                    self.peak_indices,
@@ -423,10 +420,11 @@ def peaks_from_model(model, data, sphere, relative_peak_threshold,
     sh_order : int, optional
         Maximum SH order in the SH fit.  For `sh_order`, there will be
         ``(sh_order + 1) * (sh_order + 2) / 2`` SH coefficients (default 8).
-    sh_basis_type : {None, 'mrtrix', 'fibernav'}
-        ``None`` for the default dipy basis which is the fibernav basis,
-        ``mrtrix`` for the MRtrix basis, and
-        ``fibernav`` for the FiberNavigator basis
+    sh_basis_type : {None, 'tournier07', 'descoteaux07'}
+        ``None`` for the default DIPY basis,
+        ``tournier07`` for the Tournier 2007 [2]_ basis, and
+        ``descoteaux07`` for the Descoteaux 2007 [1]_ basis
+        (``None`` defaults to ``descoteaux07``).
     sh_smooth : float, optional
         Lambda-regularization in the SH fit (default 0.0).
     npeaks : int
@@ -450,6 +448,17 @@ def peaks_from_model(model, data, sphere, relative_peak_threshold,
     pam : PeaksAndMetrics
         An object with ``gfa``, ``peak_directions``, ``peak_values``,
         ``peak_indices``, ``odf``, ``shm_coeffs`` as attributes
+
+    References
+    ----------
+    .. [1] Descoteaux, M., Angelino, E., Fitzgibbons, S. and Deriche, R.
+           Regularized, Fast, and Robust Analytical Q-ball Imaging.
+           Magn. Reson. Med. 2007;58:497-510.
+    .. [2] Tournier J.D., Calamante F. and Connelly A. Robust determination
+           of the fibre orientation distribution in diffusion MRI:
+           Non-negativity constrained super-resolved spherical deconvolution.
+           NeuroImage. 2007;35(4):1459-1472.
+
     """
     if return_sh and (B is None or invB is None):
         B, invB = sh_to_sf_matrix(
@@ -459,7 +468,7 @@ def peaks_from_model(model, data, sphere, relative_peak_threshold,
         # It is mandatory to provide B and invB to the parallel function.
         # Otherwise, a call to np.linalg.pinv is made in a subprocess and
         # makes it timeout on some system.
-        # see https://github.com/nipy/dipy/issues/253 for details
+        # see https://github.com/dipy/dipy/issues/253 for details
         return _peaks_from_model_parallel(model,
                                           data, sphere,
                                           relative_peak_threshold,
@@ -555,12 +564,12 @@ def reshape_peaks_for_visualization(peaks):
     Reshape and convert to float32 a set of peaks for visualisation with mrtrix
     or the fibernavigator.
 
-    Parameters:
+    Parameters
     -----------
     peaks: nd array (..., N, 3) or PeaksAndMetrics object
         The peaks to be reshaped and converted to float32.
 
-    Returns:
+    Returns
     --------
     peaks : nd array (..., 3*N)
     """
