@@ -6,11 +6,11 @@ docs.  In setup.py in particular, we exec this file, so it cannot import dipy
 # DIPY version information.  An empty _version_extra corresponds to a
 # full release.  '.dev' as a _version_extra string means this is a development
 # version
-_version_major = 0
-_version_minor = 14
+_version_major = 1
+_version_minor = 3
 _version_micro = 0
+# _version_extra = 'dev'
 _version_extra = ''
-#_version_extra = ''
 
 # Format expected by setup.py and doc/source/conf.py: string of form "X.Y.Z"
 __version__ = "%s.%s.%s%s" % (_version_major,
@@ -44,7 +44,7 @@ clinical decisions.
 Website
 =======
 
-Current information can always be found from the DIPY website - http://dipy.org
+Current information can always be found from the DIPY website - https://dipy.org
 
 Mailing Lists
 =============
@@ -61,9 +61,9 @@ You can find our sources and single-click downloads:
 * Documentation_ for all releases and current development tree.
 * Download as a tar/zip file the `current trunk`_.
 
-.. _main repository: http://github.com/nipy/dipy
+.. _main repository: http://github.com/dipy/dipy
 .. _Documentation: http://dipy.org
-.. _current trunk: https://github.com/nipy/dipy/archive/master.zip
+.. _current trunk: https://github.com/dipy/dipy/archive/master.zip
 
 License
 =======
@@ -72,18 +72,18 @@ DIPY is licensed under the terms of the BSD license.
 Please see the LICENSE file in the dipy distribution.
 
 DIPY uses other libraries also licensed under the BSD or the
-MIT licenses, with the only exception of the SHORE module which
-optionally uses the cvxopt library. Cvxopt is licensed
-under the GPL license.
+MIT licenses.
 """
 
 # versions for dependencies
 # Check these versions against .travis.yml and requirements.txt
-CYTHON_MIN_VERSION='0.25.1'
-NUMPY_MIN_VERSION='1.7.1'
-SCIPY_MIN_VERSION='0.9'
-NIBABEL_MIN_VERSION='2.1.0'
-H5PY_MIN_VERSION='2.4.0'
+CYTHON_MIN_VERSION = '0.29'
+NUMPY_MIN_VERSION = '1.12.0'
+SCIPY_MIN_VERSION = '1.0'
+NIBABEL_MIN_VERSION = '3.0.0'
+H5PY_MIN_VERSION = '2.5.0'
+PACKAGING_MIN_VERSION = '19.0'
+TQDM_MIN_VERSION = '4.30.0'
 
 # Main setup parameters
 NAME                = 'dipy'
@@ -91,8 +91,8 @@ MAINTAINER          = "Eleftherios Garyfallidis"
 MAINTAINER_EMAIL    = "neuroimaging@python.org"
 DESCRIPTION         = description
 LONG_DESCRIPTION    = long_description
-URL                 = "http://dipy.org"
-DOWNLOAD_URL        = "http://github.com/nipy/dipy/archives/master"
+URL                 = "https://dipy.org"
+DOWNLOAD_URL        = "https://github.com/dipy/dipy/releases"
 LICENSE             = "BSD license"
 CLASSIFIERS         = CLASSIFIERS
 AUTHOR              = "dipy developers"
@@ -107,4 +107,45 @@ PROVIDES            = ["dipy"]
 REQUIRES            = ["numpy (>=%s)" % NUMPY_MIN_VERSION,
                        "scipy (>=%s)" % SCIPY_MIN_VERSION,
                        "nibabel (>=%s)" % NIBABEL_MIN_VERSION,
-                       "h5py (>=%s)" % H5PY_MIN_VERSION]
+                       "h5py (>=%s)" % H5PY_MIN_VERSION,
+                       "packaging (>=%s)" % PACKAGING_MIN_VERSION,
+                       "tqdm"]
+EXTRAS_REQUIRE = {
+    "test": [
+        "pytest",
+        "coverage",
+        "coveralls",
+        "codecov",
+    ],
+    "doc": [
+        "cython",
+        "numpy",
+        "scipy",
+        "nibabel>=3.0.0",
+        "h5py",
+        "h5py<3.0.0; sys_platform == 'win32'",
+        "cvxpy",
+        "pandas",
+        "tables",
+        "matplotlib",
+        "fury>=0.6"
+        "scikit-learn",
+        "scikit-image",
+        "statsmodels",
+    ],
+    "viz": [
+        "fury>=0.6",
+        "matplotlib"
+    ],
+    "ml": [
+        "scikit_learn",
+        "pandas",
+        "statsmodels"
+        "tables",
+        "tensorflow"
+    ]
+
+}
+
+EXTRAS_REQUIRE["all"] = list(set([a[i] for a in list(EXTRAS_REQUIRE.values())
+                                  for i in range(len(a))]))
