@@ -1,22 +1,23 @@
-from __future__ import division, print_function, absolute_import
 
 import os
 import sys
 import subprocess
 
-from dipy.utils.six.moves import configparser
+import configparser
 
 COMMIT_INFO_FNAME = 'COMMIT_INFO.txt'
 
+
 def pkg_commit_hash(pkg_path):
-    ''' Get short form of commit hash given directory `pkg_path`
+    """ Get short form of commit hash given directory `pkg_path`
 
     There should be a file called 'COMMIT_INFO.txt' in `pkg_path`.  This is a
-    file in INI file format, with at least one section: ``commit hash``, and two
-    variables ``archive_subst_hash`` and ``install_hash``.  The first has a
-    substitution pattern in it which may have been filled by the execution of
-    ``git archive`` if this is an archive generated that way.  The second is
-    filled in by the installation, if the installation is from a git archive.
+    file in INI file format, with at least one section: ``commit hash``, and
+    two variables ``archive_subst_hash`` and ``install_hash``.  The first has
+    a substitution pattern in it which may have been filled by the execution
+    of ``git archive`` if this is an archive generated that way.  The second
+    is filled in by the installation, if the installation is from a git
+    archive.
 
     We get the commit hash from (in order of preference):
 
@@ -37,7 +38,7 @@ def pkg_commit_hash(pkg_path):
        Where we got the hash from - description
     hash_str : str
        short form of hash
-    '''
+    """
     # Try and get commit from written commit text file
     pth = os.path.join(pkg_path, COMMIT_INFO_FNAME)
     if not os.path.isfile(pth):
@@ -62,7 +63,7 @@ def pkg_commit_hash(pkg_path):
 
 
 def get_pkg_info(pkg_path):
-    ''' Return dict describing the context of this package
+    """ Return dict describing the context of this package
 
     Parameters
     ------------
@@ -73,7 +74,7 @@ def get_pkg_info(pkg_path):
     ----------
     context : dict
        with named parameters of interest
-    '''
+    """
     src, hsh = pkg_commit_hash(pkg_path)
     import numpy
     import dipy
