@@ -2,9 +2,9 @@
 import numpy as np
 from numpy.lib.stride_tricks import as_strided
 
-from ..core.ndindex import ndindex
-from .quick_squash import quick_squash as _squash
-from .base import ReconstFit
+from dipy.core.ndindex import ndindex
+from dipy.reconst.quick_squash import quick_squash as _squash
+from dipy.reconst.base import ReconstFit
 
 
 def multi_voxel_fit(single_voxel_fit):
@@ -66,10 +66,6 @@ class MultiVoxelFit(ReconstFit):
         Predict for the multi-voxel object using each single-object's
         prediction API, with S0 provided from an array.
         """
-        if not hasattr(self.model, 'predict'):
-            msg = "This model does not have prediction implemented yet"
-            raise NotImplementedError(msg)
-
         S0 = kwargs.get('S0', np.ones(self.fit_array.shape))
         idx = ndindex(self.fit_array.shape)
         ijk = next(idx)
@@ -85,6 +81,10 @@ class MultiVoxelFit(ReconstFit):
         while self.fit_array[ijk] is None:
             ijk = next(idx)
 
+        if not hasattr(self.fit_array[ijk], 'predict'):
+            msg = "This model does not have prediction implemented yet"
+            raise NotImplementedError(msg)
+
         first_pred = self.fit_array[ijk].predict(*args, **kwargs)
         result = np.zeros(self.fit_array.shape + (first_pred.shape[-1],))
         result[ijk] = first_pred
