@@ -1,7 +1,7 @@
-from __future__ import division
 
 from warnings import warn
 from math import factorial
+from distutils.version import LooseVersion
 
 import numpy as np
 
@@ -31,32 +31,32 @@ class ShoreModel(Cache):
                 S(\mathbf{q})= \sum_{i=0}^I  c_{i} \phi_{i}(\mathbf{q}).
             \end{equation}
 
-    where $\mathbf{q}$ is the wavector which corresponds to different gradient
-    directions. Numerous continuous functions $\phi_i$ can be used to model
-    $S$. Some are presented in [2,3,4]_.
+    where $\mathbf{q}$ is the wave vector which corresponds to different
+    gradient directions. Numerous continuous functions $\phi_i$ can be used to
+    model $S$. Some are presented in [2,3,4]_.
 
     From the $c_i$ coefficients, there exist analytical formulae to estimate
-    the ODF, the return to the origin porbability (RTOP), the mean square
+    the ODF, the return to the origin probability (RTOP), the mean square
     displacement (MSD), amongst others [5]_.
 
     References
     ----------
-    .. [1] Ozarslan E. et. al, "Simple harmonic oscillator based reconstruction
+    .. [1] Ozarslan E. et al., "Simple harmonic oscillator based reconstruction
            and estimation for one-dimensional q-space magnetic resonance
-           1D-SHORE)", eapoc Intl Soc Mag Reson Med, vol. 16, p. 35., 2008.
+           1D-SHORE)", Proc Intl Soc Mag Reson Med, vol. 16, p. 35., 2008.
 
-    .. [2] Merlet S. et. al, "Continuous diffusion signal, EAP and ODF
+    .. [2] Merlet S. et al., "Continuous diffusion signal, EAP and ODF
            estimation via Compressive Sensing in diffusion MRI", Medical
            Image Analysis, 2013.
 
-    .. [3] Rathi Y. et. al, "Sparse multi-shell diffusion imaging", MICCAI,
+    .. [3] Rathi Y. et al., "Sparse multi-shell diffusion imaging", MICCAI,
            2011.
 
-    .. [4] Cheng J. et. al, "Theoretical Analysis and eapactical Insights on
+    .. [4] Cheng J. et al., "Theoretical Analysis and eapactical Insights on
            EAP Estimation via a Unified HARDI Framework", MICCAI workshop on
            Computational Diffusion MRI, 2011.
 
-    .. [5] Ozarslan E. et. al, "Mean apparent propagator (MAP) MRI: A novel
+    .. [5] Ozarslan E. et al., "Mean apparent propagator (MAP) MRI: A novel
            diffusion imaging method for mapping tissue microstructure",
            NeuroImage, 2013.
 
@@ -93,7 +93,7 @@ class ShoreModel(Cache):
                     S(\mathbf{q})= \sum_{i=0}^I  c_{i} \phi_{i}(\mathbf{q}).
                 \end{equation}
 
-        where $\mathbf{q}$ is the wavector which corresponds to different
+        where $\mathbf{q}$ is the wave vector which corresponds to different
         gradient directions.
 
         From the $c_i$ coefficients, there exists an analytical formula to
@@ -137,7 +137,7 @@ class ShoreModel(Cache):
         ODF estimation via Compressive Sensing in diffusion MRI", Medical
         Image Analysis, 2013.
 
-        .. [2] Cheng J. et al., "Theoretical Analysis and eapactical Insights
+        .. [2] Cheng J. et al., "Theoretical Analysis and Practical Insights
         on EAP Estimation via a Unified HARDI Framework", MICCAI workshop on
         Computational Diffusion MRI, 2011.
 
@@ -152,13 +152,12 @@ class ShoreModel(Cache):
         with respect to the SHORE basis and compute the real and analytical
         ODF.
 
-        from dipy.data import get_data,get_sphere
-        sphere = get_sphere('symmetric724')
-        fimg, fbvals, fbvecs = get_data('ISBI_testing_2shells_table')
+        from dipy.data import get_fnames, default_sphere
+        fimg, fbvals, fbvecs = get_fnames('ISBI_testing_2shells_table')
         bvals, bvecs = read_bvals_bvecs(fbvals, fbvecs)
         gtab = gradient_table(bvals, bvecs)
-        from dipy.sims.voxel import SticksAndBall
-        data, golden_directions = SticksAndBall(
+        from dipy.sims.voxel import sticks_and_ball
+        data, golden_directions = sticks_and_ball(
             gtab, d=0.0015, S0=1., angles=[(0, 0), (90, 0)],
             fractions=[50, 50], snr=None)
         from dipy.reconst.canal import ShoreModel
@@ -167,7 +166,7 @@ class ShoreModel(Cache):
         asm = ShoreModel(gtab, radial_order=radial_order, zeta=zeta,
                          lambdaN=1e-8, lambdaL=1e-8)
         asmfit = asm.fit(data)
-        odf= asmfit.odf(sphere)
+        odf= asmfit.odf(default_sphere)
         """
 
         self.bvals = gtab.bvals
@@ -210,7 +209,6 @@ class ShoreModel(Cache):
 
     @multi_voxel_fit
     def fit(self, data):
-
         Lshore = l_shore(self.radial_order)
         Nshore = n_shore(self.radial_order)
         # Generate the SHORE basis
@@ -247,34 +245,41 @@ class ShoreModel(Cache):
             M0 = M[self.gtab.b0s_mask, :]
 
             c = cvxpy.Variable(M.shape[1])
-            design_matrix = cvxpy.Constant(M)
+            if LooseVersion(cvxpy.__version__) < LooseVersion('1.1'):
+                design_matrix = cvxpy.Constant(M) * c
+            else:
+                design_matrix = cvxpy.Constant(M) @ c
             objective = cvxpy.Minimize(
-                cvxpy.sum_squares(design_matrix * c - data_norm) +
+                cvxpy.sum_squares(design_matrix - data_norm) +
                 self.lambdaN * cvxpy.quad_form(c, Nshore) +
                 self.lambdaL * cvxpy.quad_form(c, Lshore)
             )
 
             if not self.positive_constraint:
-                constraints = [M0[0] * c == 1]
+                if LooseVersion(cvxpy.__version__) < LooseVersion('1.1'):
+                    constraints = [M0[0] * c == 1]
+                else:
+                    constraints = [M0[0] @ c == 1]
             else:
                 lg = int(np.floor(self.pos_grid ** 3 / 2))
                 v, t = create_rspace(self.pos_grid, self.pos_radius)
-                psi = self.cache_get(
-                    'shore_matrix_positive_constraint',
-                    key=(self.pos_grid, self.pos_radius)
-                )
+                psi = self.cache_get('shore_matrix_positive_constraint',
+                                     key=(self.pos_grid, self.pos_radius))
                 if psi is None:
                     psi = shore_matrix_pdf(
                         self.radial_order, self.zeta, t[:lg])
                     self.cache_set(
                         'shore_matrix_positive_constraint',
                         (self.pos_grid, self.pos_radius), psi)
-                constraints = [M0[0] * c == 1., psi * c > 1e-3]
+                if LooseVersion(cvxpy.__version__) < LooseVersion('1.1'):
+                    constraints = [(M0[0] * c) == 1., (psi * c) >= 1e-3]
+                else:
+                    constraints = [(M0[0] @ c) == 1., (psi @ c) >= 1e-3]
             prob = cvxpy.Problem(objective, constraints)
             try:
                 prob.solve(solver=self.cvxpy_solver)
                 coef = np.asarray(c.value).squeeze()
-            except:
+            except Exception:
                 warn('Optimization did not find a solution')
                 coef = np.zeros(M.shape[1])
         return ShoreFit(self, coef)
@@ -412,7 +417,7 @@ class ShoreFit():
 
         References
         ----------
-        .. [1] Ozarslan E. et. al, "Mean apparent propagator (MAP) MRI: A novel
+        .. [1] Ozarslan E. et al., "Mean apparent propagator (MAP) MRI: A novel
         diffusion imaging method for mapping tissue microstructure",
         NeuroImage, 2013.
         """
@@ -432,7 +437,7 @@ class ShoreFit():
 
         References
         ----------
-        .. [1] Ozarslan E. et. al, "Mean apparent propagator (MAP) MRI: A novel
+        .. [1] Ozarslan E. et al., "Mean apparent propagator (MAP) MRI: A novel
         diffusion imaging method for mapping tissue microstructure",
         NeuroImage, 2013.
         """
@@ -458,11 +463,11 @@ class ShoreFit():
                 \end{equation}
 
         where $\hat{\mathbf{r}}$ is a point in the 3D propagator space (see Wu
-        et. al [1]_).
+        et al. [1]_).
 
         References
         ----------
-        .. [1] Wu Y. et. al, "Hybrid diffusion imaging", NeuroImage, vol 36,
+        .. [1] Wu Y. et al., "Hybrid diffusion imaging", NeuroImage, vol 36,
         p. 617-629, 2007.
         """
         msd = 0
@@ -526,7 +531,7 @@ def shore_matrix(radial_order, zeta, gtab, tau=1 / (4 * np.pi ** 2)):
 
     References
     ----------
-    .. [1] Merlet S. et. al, "Continuous diffusion signal, EAP and
+    .. [1] Merlet S. et al., "Continuous diffusion signal, EAP and
     ODF estimation via Compressive Sensing in diffusion MRI", Medical
     Image Analysis, 2013.
 
@@ -576,7 +581,7 @@ def shore_matrix_pdf(radial_order, zeta, rtab):
 
     References
     ----------
-    .. [1] Merlet S. et. al, "Continuous diffusion signal, EAP and
+    .. [1] Merlet S. et al., "Continuous diffusion signal, EAP and
     ODF estimation via Compressive Sensing in diffusion MRI", Medical
     Image Analysis, 2013.
     """
@@ -620,7 +625,7 @@ def shore_matrix_odf(radial_order, zeta, sphere_vertices):
 
     References
     ----------
-    .. [1] Merlet S. et. al, "Continuous diffusion signal, EAP and
+    .. [1] Merlet S. et al., "Continuous diffusion signal, EAP and
     ODF estimation via Compressive Sensing in diffusion MRI", Medical
     Image Analysis, 2013.
     """
