@@ -1,35 +1,38 @@
 import numpy as np
-from dipy.data import get_data, dsi_voxels
+
+from dipy.data import get_fnames, dsi_voxels, get_sphere, default_sphere
 from dipy.core.sphere import Sphere
 from dipy.core.gradients import gradient_table
-from dipy.sims.voxel import SticksAndBall
-from dipy.reconst.gqi import GeneralizedQSamplingModel
-from dipy.data import get_sphere
-from numpy.testing import (assert_equal,
-                           assert_almost_equal,
-                           run_module_suite)
-from dipy.reconst.tests.test_dsi import sticks_and_ball_dummies
 from dipy.core.subdivide_octahedron import create_unit_sphere
 from dipy.core.sphere_stats import angular_similarity
+from dipy.reconst.gqi import GeneralizedQSamplingModel
+from dipy.reconst.tests.test_dsi import sticks_and_ball_dummies
+from dipy.sims.voxel import sticks_and_ball
 from dipy.reconst.odf import gfa
 from dipy.direction.peaks import peak_directions
 
+from numpy.testing import (assert_equal,
+                           assert_almost_equal,
+                           run_module_suite)
+
+
+
 
 def test_gqi():
-    # load symmetric 724 sphere
-    sphere = get_sphere('symmetric724')
+    # load repulsion 724 sphere
+    sphere = default_sphere
     # load icosahedron sphere
     sphere2 = create_unit_sphere(5)
-    btable = np.loadtxt(get_data('dsi515btable'))
+    btable = np.loadtxt(get_fnames('dsi515btable'))
     bvals = btable[:, 0]
     bvecs = btable[:, 1:]
     gtab = gradient_table(bvals, bvecs)
-    data, golden_directions = SticksAndBall(gtab, d=0.0015,
-                                            S0=100, angles=[(0, 0), (90, 0)],
-                                            fractions=[50, 50], snr=None)
+    data, golden_directions = sticks_and_ball(gtab, d=0.0015, S0=100,
+                                              angles=[(0, 0), (90, 0)],
+                                              fractions=[50, 50], snr=None)
     gq = GeneralizedQSamplingModel(gtab, method='gqi2', sampling_length=1.4)
 
-    # symmetric724
+    # repulsion724
     gqfit = gq.fit(data)
     odf = gqfit.odf(sphere)
     directions, values, indices = peak_directions(odf, sphere, .35, 25)
