@@ -1,12 +1,18 @@
+import warnings
 import numpy as np
 import numpy.testing as npt
-import nibabel as nib
+import pytest
 import dipy.reconst.sfm as sfm
 import dipy.data as dpd
 import dipy.core.gradients as grad
 import dipy.sims.voxel as sims
 import dipy.core.optimize as opt
 import dipy.reconst.cross_validation as xval
+from dipy.io.gradients import read_bvals_bvecs
+from dipy.io.image import load_nifti_data
+
+needs_sklearn = pytest.mark.skipif(not sfm.has_sklearn,
+                                   reason="Requires Scikit-Learn")
 
 
 def test_design_matrix():
@@ -19,10 +25,10 @@ def test_design_matrix():
                      (np.sum(~gtab.b0s_mask), sphere.vertices.shape[0]))
 
 
-@npt.dec.skipif(not sfm.has_sklearn)
+@needs_sklearn
 def test_sfm():
-    fdata, fbvals, fbvecs = dpd.get_data()
-    data = nib.load(fdata).get_data()
+    fdata, fbvals, fbvecs = dpd.get_fnames()
+    data = load_nifti_data(fdata)
     gtab = grad.gradient_table(fbvals, fbvecs)
     for iso in [sfm.ExponentialIsotropicModel, None]:
         sfmodel = sfm.SparseFascicleModel(gtab, isotropic=iso)
@@ -47,13 +53,12 @@ def test_sfm():
             np.zeros(sfmodel.design_matrix[0].shape[-1]))
 
 
-@npt.dec.skipif(not sfm.has_sklearn)
+@needs_sklearn
 def test_predict():
     SNR = 1000
     S0 = 100
-    _, fbvals, fbvecs = dpd.get_data('small_64D')
-    bvals = np.load(fbvals)
-    bvecs = np.load(fbvecs)
+    _, fbvals, fbvecs = dpd.get_fnames('small_64D')
+    bvals, bvecs = read_bvals_bvecs(fbvals, fbvecs)
     gtab = grad.gradient_table(bvals, bvecs)
     mevals = np.array(([0.0015, 0.0003, 0.0003],
                        [0.0015, 0.0003, 0.0003]))
@@ -71,10 +76,57 @@ def test_predict():
     new_pred = sffit.predict(new_gtab)
     npt.assert_(xval.coeff_of_determination(new_pred, S[::2]) > 97)
 
+    # Should be possible to predict for a single direction:
+    with warnings.catch_warnings():
+        warnings.simplefilter("ignore", category=UserWarning)
+        new_gtab = grad.gradient_table(bvals[1][None], bvecs[1][None, :])
+    new_pred = sffit.predict(new_gtab)
+
+    # Fitting and predicting with a volume of data:
+    fdata, fbval, fbvec = dpd.get_fnames('small_25')
+    gtab = grad.gradient_table(fbval, fbvec)
+    data = load_nifti_data(fdata)
+    sfmodel = sfm.SparseFascicleModel(gtab, response=[0.0015, 0.0003, 0.0003])
+    sffit = sfmodel.fit(data)
+    pred = sffit.predict()
+
+    # Should be possible to predict using a different gtab:
+    new_gtab = grad.gradient_table(bvals[::2], bvecs[::2])
+    new_pred = sffit.predict(new_gtab)
+    npt.assert_equal(new_pred.shape, data.shape[:-1] + bvals[::2].shape, )
+
+    # Should be possible to predict for a single direction:
+    with warnings.catch_warnings():
+        warnings.simplefilter("ignore", category=UserWarning)
+        new_gtab = grad.gradient_table(bvals[1][None], bvecs[1][None, :])
+    new_pred = sffit.predict(new_gtab)
+    npt.assert_equal(new_pred.shape, data.shape[:-1])
+
+    # Fitting and predicting with masked data:
+    mask = np.zeros(data.shape[:3])
+    mask[2:5, 2:5, :] = 1
+    sffit = sfmodel.fit(data, mask=mask)
+    pred = sffit.predict()
+    npt.assert_equal(pred.shape, data.shape)
+
+    # Should be possible to predict using a different gtab:
+    new_gtab = grad.gradient_table(bvals[::2], bvecs[::2])
+    new_pred = sffit.predict(new_gtab)
+    npt.assert_equal(new_pred.shape, data.shape[:-1] + bvals[::2].shape,)
+    npt.assert_equal(new_pred[0, 0, 0], 0)
+
+    # Should be possible to predict for a single direction:
+    with warnings.catch_warnings():
+        warnings.simplefilter("ignore", category=UserWarning)
+        new_gtab = grad.gradient_table(bvals[1][None], bvecs[1][None, :])
+    new_pred = sffit.predict(new_gtab)
+    npt.assert_equal(new_pred.shape, data.shape[:-1])
+    npt.assert_equal(new_pred[0, 0, 0], 0)
+
 
 def test_sfm_background():
-    fdata, fbvals, fbvecs = dpd.get_data()
-    data = nib.load(fdata).get_data()
+    fdata, fbvals, fbvecs = dpd.get_fnames()
+    data = load_nifti_data(fdata)
     gtab = grad.gradient_table(fbvals, fbvecs)
     to_fit = data[0, 0, 0]
     to_fit[gtab.b0s_mask] = 0
@@ -84,8 +136,8 @@ def test_sfm_background():
 
 
 def test_sfm_stick():
-    fdata, fbvals, fbvecs = dpd.get_data()
-    data = nib.load(fdata).get_data()
+    fdata, fbvals, fbvecs = dpd.get_fnames()
+    data = load_nifti_data(fdata)
     gtab = grad.gradient_table(fbvals, fbvecs)
     sfmodel = sfm.SparseFascicleModel(gtab, solver='NNLS',
                                       response=[0.001, 0, 0])
@@ -118,7 +170,7 @@ def test_sfm_sklearnlinearsolver():
         def fit(self, X, y):
             self.coef_ = np.ones(X.shape[-1])
 
-    fdata, fbvals, fbvecs = dpd.get_data()
+    fdata, fbvals, fbvecs = dpd.get_fnames()
     gtab = grad.gradient_table(fbvals, fbvecs)
     sfmodel = sfm.SparseFascicleModel(gtab, solver=SillySolver())
 
@@ -129,10 +181,10 @@ def test_sfm_sklearnlinearsolver():
                       solver=EvenSillierSolver())
 
 
-@npt.dec.skipif(not sfm.has_sklearn)
+@needs_sklearn
 def test_exponential_iso():
-    fdata, fbvals, fbvecs = dpd.get_data()
-    data_dti = nib.load(fdata).get_data()
+    fdata, fbvals, fbvecs = dpd.get_fnames()
+    data_dti = load_nifti_data(fdata)
     gtab_dti = grad.gradient_table(fbvals, fbvecs)
     data_multi, gtab_multi = dpd.dsi_deconv_voxels()
 
@@ -142,8 +194,28 @@ def test_exponential_iso():
 
         sffit1 = sfmodel.fit(data[0, 0, 0])
         sphere = dpd.get_sphere()
-        sffit1.odf(sphere)
-        sffit1.predict(gtab)
+        odf = sffit1.odf(sphere)
+        pred = sffit1.predict(gtab)
+        npt.assert_equal(pred.shape, data[0, 0, 0].shape)
+        npt.assert_equal(odf.shape,
+                         data[0, 0, 0].shape[:-1] + (sphere.x.shape[0],))
+
+        sffit2 = sfmodel.fit(data)
+        sphere = dpd.get_sphere()
+        odf = sffit2.odf(sphere)
+        pred = sffit2.predict(gtab)
+        npt.assert_equal(pred.shape, data.shape)
+        npt.assert_equal(odf.shape,
+                         data.shape[:-1] + (sphere.x.shape[0],))
+
+        mask = np.zeros(data.shape[:3])
+        mask[2:5, 2:5, :] = 1
+        sffit3 = sfmodel.fit(data, mask=mask)
+        sphere = dpd.get_sphere()
+        odf = sffit3.odf(sphere)
+        pred = sffit3.predict(gtab)
+        npt.assert_equal(pred.shape, data.shape)
+        npt.assert_equal(odf.shape, data.shape[:-1] + (sphere.x.shape[0],))
 
         SNR = 1000
         S0 = 100
