@@ -9,15 +9,6 @@ def make_vecs_vals(shape):
     return randn(*(shape)), randn(*(shape[:-2] + shape[-1:]))
 
 
-try:
-    np.einsum
-except AttributeError:
-    with_einsum = dec.skipif(True, "Need einsum for benchmark")
-else:
-    def with_einsum(f): return f
-
-
-@with_einsum
 def test_vec_val_vect():
     for shape0 in ((10,), (100,), (10, 12), (12, 10, 5)):
         for shape1 in ((3, 3), (4, 3), (3, 4)):
