@@ -2,6 +2,7 @@ import operator
 import numpy as np
 from time import time
 from abc import ABCMeta, abstractmethod
+import logging
 
 from dipy.segment.metric import Metric
 from dipy.segment.metric import ResampleFeature
@@ -10,6 +11,9 @@ from dipy.segment.metric import MinimumAverageDirectFlipMetric
 from dipy.tracking.streamline import set_number_of_points, nbytes
 
 
+logger = logging.getLogger(__name__)
+
+
 class Identity:
     """ Provides identity indexing functionality.
 
@@ -439,11 +443,14 @@ class QuickBundles(Clustering):
     Examples
     --------
     >>> from dipy.segment.clustering import QuickBundles
-    >>> from dipy.data import get_data
-    >>> from nibabel import trackvis as tv
-    >>> streams, hdr = tv.read(get_data('fornix'))
-    >>> streamlines = [i[0] for i in streams]
-    >>> # Segment fornix with a treshold of 10mm and streamlines resampled
+    >>> from dipy.data import get_fnames
+    >>> from dipy.io.streamline import load_tractogram
+    >>> from dipy.tracking.streamline import Streamlines
+    >>> fname = get_fnames('fornix')
+    >>> fornix = load_tractogram(fname, 'same',
+    ...                          bbox_valid_check=False).streamlines
+    >>> streamlines = Streamlines(fornix)
+    >>> # Segment fornix with a threshold of 10mm and streamlines resampled
     >>> # to 12 points.
     >>> qb = QuickBundles(threshold=10.)
     >>> clusters = qb.cluster(streamlines)
@@ -595,6 +602,9 @@ class TreeCluster(ClusterCentroid):
     @property
     def is_leaf(self):
         return len(self.children) == 0
+    
+    def return_indices(self):
+        return self.children
 
 
 class TreeClusterMap(ClusterMap):
@@ -662,7 +672,7 @@ class TreeClusterMap(ClusterMap):
 
 
 def qbx_and_merge(streamlines, thresholds,
-                  nb_pts=20, select_randomly=None, rng=None, verbose=True):
+                  nb_pts=20, select_randomly=None, rng=None, verbose=False):
     """ Run QuickBundlesX and then run again on the centroids of the last layer
 
     Running again QuickBundles at a layer has the effect of merging
@@ -683,9 +693,8 @@ def qbx_and_merge(streamlines, thresholds,
         streamlines are used.
     rng : RandomState
         If None then RandomState is initialized internally.
-    verbose : bool
-        If True print information in stdout.
-
+    verbose : bool, optional.
+        If True, log information. Default False.
     Returns
     -------
     clusters : obj
@@ -703,8 +712,7 @@ def qbx_and_merge(streamlines, thresholds,
                         of the, International Society of Magnetic Resonance
                         in Medicine (ISMRM). Singapore, 4187, 2016.
     """
-    if verbose:
-        t = time()
+    t = time()
     len_s = len(streamlines)
     if select_randomly is None:
         select_randomly = len_s
@@ -716,20 +724,19 @@ def qbx_and_merge(streamlines, thresholds,
     sample_streamlines = set_number_of_points(streamlines, nb_pts)
 
     if verbose:
-        print(' Resampled to {} points'.format(nb_pts))
-        print(' Size is %0.3f MB' % (nbytes(sample_streamlines),))
-        print(' Duration of resampling is %0.3f sec.' % (time() - t,))
-        print(' QBX phase starting...')
+        logger.info(' Resampled to {} points'.format(nb_pts))
+        logger.info(' Size is %0.3f MB' % (nbytes(sample_streamlines),))
+        logger.info(' Duration of resampling is %0.3f sec.' % (time() - t,))
+        logger.info(' QBX phase starting...')
 
     qbx = QuickBundlesX(thresholds,
                         metric=AveragePointwiseEuclideanMetric())
 
-    if verbose:
-        t1 = time()
+    t1 = time()
     qbx_clusters = qbx.cluster(sample_streamlines, ordering=indices)
 
     if verbose:
-        print(' Merging phase starting ...')
+        logger.info(' Merging phase starting ...')
 
     qbx_merge = QuickBundlesX([thresholds[-1]],
                               metric=AveragePointwiseEuclideanMetric())
@@ -754,9 +761,9 @@ def qbx_and_merge(streamlines, thresholds,
     merged_cluster_map.refdata = streamlines
 
     if verbose:
-        print(' QuickBundlesX time for %d random streamlines'
-              % (select_randomly,))
+        logger.info(' QuickBundlesX time for %d random streamlines'
+                    % (select_randomly,))
 
-        print(' Duration %0.3f sec. \n' % (time() - t1,))
+        logger.info(' Duration %0.3f sec. \n' % (time() - t1,))
 
     return merged_cluster_map
