@@ -1,18 +1,17 @@
-from __future__ import division
 
 import numpy as np
 
 from numpy.testing import (assert_, assert_array_almost_equal, run_module_suite)
 
-from dipy.data import get_data
+from dipy.data import get_fnames
 from dipy.reconst.dti import TensorModel
 from dipy.sims.phantom import orbital_phantom
 from dipy.core.gradients import gradient_table
+from dipy.io.gradients import read_bvals_bvecs
 
 
-fimg, fbvals, fbvecs = get_data('small_64D')
-bvals = np.load(fbvals)
-bvecs = np.load(fbvecs)
+fimg, fbvals, fbvecs = get_fnames('small_64D')
+bvals, bvecs = read_bvals_bvecs(fbvals, fbvecs)
 bvecs[np.isnan(bvecs)] = 0
 
 gtab = gradient_table(bvals, bvecs)
