@@ -1,7 +1,8 @@
 
+import warnings
 import numpy as np
-from dipy.testing import assert_true, assert_false
-from numpy.testing import (assert_array_equal, assert_array_almost_equal,
+from dipy.testing import assert_true
+from numpy.testing import (assert_array_almost_equal, assert_warns,
                            assert_equal, assert_almost_equal)
 from dipy.tracking import distances as pf
 from dipy.tracking.streamline import set_number_of_points
@@ -9,7 +10,7 @@ from dipy.data import get_fnames
 from dipy.io.streamline import load_tractogram
 
 
-def test_LSCv2():
+def test_LSCv2(verbose=False):
     xyz1 = np.array([[1, 0, 0], [2, 0, 0], [3, 0, 0]], dtype='float32')
     xyz2 = np.array([[1, 0, 0], [1, 2, 0], [1, 3, 0]], dtype='float32')
     xyz3 = np.array([[1.1, 0, 0], [1, 2, 0], [1, 3, 0]], dtype='float32')
@@ -21,16 +22,8 @@ def test_LSCv2():
     T = [xyz1, xyz2, xyz3, xyz4, xyz5, xyz6]
     pf.local_skeleton_clustering(T, 0.2)
 
-    # print C
-    # print len(C)
-
     pf.local_skeleton_clustering_3pts(T, 0.2)
 
-    # print C2
-    # print len(C2)
-
-    # """
-
     for i in range(40):
         xyz = np.random.rand(3, 3).astype('f4')
         T.append(xyz)
@@ -39,14 +32,16 @@ def test_LSCv2():
     t1 = time()
     C3 = pf.local_skeleton_clustering(T, .5)
     t2 = time()
-    print(t2-t1)
-    print(len(C3))
+    if verbose:
+        print(t2-t1)
+        print(len(C3))
 
     t1 = time()
     C4 = pf.local_skeleton_clustering_3pts(T, .5)
     t2 = time()
-    print(t2-t1)
-    print(len(C4))
+    if verbose:
+        print(t2-t1)
+        print(len(C4))
 
     for c in C3:
         assert_equal(np.sum(C3[c]['hidden']-C4[c]['hidden']), 0)
@@ -58,8 +53,9 @@ def test_LSCv2():
     t1 = time()
     C5 = pf.local_skeleton_clustering(T2, .5)
     t2 = time()
-    print(t2-t1)
-    print(len(C5))
+    if verbose:
+        print(t2-t1)
+        print(len(C5))
 
     fname = get_fnames('fornix')
     fornix = load_tractogram(fname, 'same',
@@ -67,11 +63,13 @@ def test_LSCv2():
 
     T3 = set_number_of_points(fornix, 6)
 
-    print('lenT3', len(T3))
+    if verbose:
+        print('lenT3', len(T3))
 
     C = pf.local_skeleton_clustering(T3, 10.)
 
-    print('lenC', len(C))
+    if verbose:
+        print('lenC', len(C))
 
     """
     try:
@@ -119,11 +117,21 @@ def test_bundles_distances_mam():
                      dtype='float32')
     tracksA = [xyz1A, xyz2A]
     tracksB = [xyz1B, xyz1A, xyz2A]
-    for metric in ('avg', 'min', 'max'):
-        pf.bundles_distances_mam(tracksA, tracksB, metric=metric)
+
+    with assert_warns(UserWarning):
+        for metric in ('avg', 'min', 'max'):
+            pf.bundles_distances_mam(tracksA, tracksB, metric=metric)
+
+    with warnings.catch_warnings(record=True) as w:
+        warnings.simplefilter("always", category=UserWarning)
+        _ = pf.bundles_distances_mam(tracksA, tracksB)
+        print(w)
+        assert_true(len(w) == 1)
+        assert_true(issubclass(w[0].category, UserWarning))
+        assert_true("not have the same number of points" in str(w[0].message))
 
 
-def test_bundles_distances_mdf():
+def test_bundles_distances_mdf(verbose=False):
     xyz1A = np.array([[0, 0, 0], [1, 0, 0], [2, 0, 0]], dtype='float32')
     xyz2A = np.array([[0, 1, 1], [1, 0, 1], [2, 3, -2]], dtype='float32')
     xyz3A = np.array([[0, 0, 0], [1, 0, 0], [3, 0, 0]], dtype='float32')
@@ -131,7 +139,8 @@ def test_bundles_distances_mdf():
 
     tracksA = [xyz1A, xyz2A]
     tracksB = [xyz1B, xyz1A, xyz2A]
-    pf.bundles_distances_mdf(tracksA, tracksB)
+    with assert_warns(UserWarning):
+        pf.bundles_distances_mdf(tracksA, tracksB)
 
     tracksA = [xyz1A, xyz1A]
     tracksB = [xyz1A, xyz1A]
@@ -142,8 +151,10 @@ def test_bundles_distances_mdf():
     tracksA = [xyz1A, xyz3A]
     tracksB = [xyz2A]
 
-    DM2 = pf.bundles_distances_mdf(tracksA, tracksB)
-    print(DM2)
+    with assert_warns(UserWarning):
+        DM2 = pf.bundles_distances_mdf(tracksA, tracksB)
+    if verbose:
+        print(DM2)
 
     # assert_array_almost_equal(DM2,np.zeros((2,2)))
     DM = np.zeros(DM2.shape)
@@ -152,17 +163,27 @@ def test_bundles_distances_mdf():
             md = np.sum(np.sqrt(np.sum((ta-tb)**2, axis=1)))/3.
             md2 = np.sum(np.sqrt(np.sum((ta-tb[::-1])**2, axis=1)))/3.
             DM[a, b] = np.min((md, md2))
-    print(DM)
 
-    print('--------------')
-    for t in tracksA:
-        print(t)
-    print('--------------')
-    for t in tracksB:
-        print(t)
+    if verbose:
+        print(DM)
+
+        print('--------------')
+        for t in tracksA:
+            print(t)
+        print('--------------')
+        for t in tracksB:
+            print(t)
 
     assert_array_almost_equal(DM, DM2, 4)
 
+    with warnings.catch_warnings(record=True) as w:
+        warnings.simplefilter("always", category=UserWarning)
+        _ = pf.bundles_distances_mdf(tracksA, tracksB[:2])
+        print(w)
+        assert_true(len(w) == 1)
+        assert_true(issubclass(w[0].category, UserWarning))
+        assert_true("not have the same number of points" in str(w[0].message))
+
 
 def test_mam_distances():
     xyz1 = np.array([[0, 0, 0], [1, 0, 0], [2, 0, 0], [3, 0, 0]])
@@ -201,50 +222,50 @@ def test_approx_mdl_traj():
     assert_equal(len(xyza2), 8)
     assert_array_almost_equal(
         xyza1,
-        np.array([[  0.00000000e+00,   1.00000000e+00,   0.00000000e+00],
-                  [  9.39692621e-01,   3.42020143e-01,   1.22173048e+00],
-                  [  6.42787610e-01,  -7.66044443e-01,   2.44346095e+00],
-                  [ -5.00000000e-01,  -8.66025404e-01,   3.66519143e+00],
-                  [ -9.84807753e-01,   1.73648178e-01,   4.88692191e+00],
-                  [ -1.73648178e-01,   9.84807753e-01,   6.10865238e+00],
-                  [  8.66025404e-01,   5.00000000e-01,   7.33038286e+00],
-                  [  7.66044443e-01,  -6.42787610e-01,   8.55211333e+00],
-                  [ -3.42020143e-01,  -9.39692621e-01,   9.77384381e+00],
-                  [ -1.00000000e+00,  -4.28626380e-16,   1.09955743e+01]]))
+        np.array([[0.00000000e+00, 1.00000000e+00, 0.00000000e+00],
+                  [9.39692621e-01, 3.42020143e-01, 1.22173048e+00],
+                  [6.42787610e-01, -7.66044443e-01, 2.44346095e+00],
+                  [-5.00000000e-01, -8.66025404e-01, 3.66519143e+00],
+                  [-9.84807753e-01, 1.73648178e-01, 4.88692191e+00],
+                  [-1.73648178e-01, 9.84807753e-01, 6.10865238e+00],
+                  [8.66025404e-01, 5.00000000e-01, 7.33038286e+00],
+                  [7.66044443e-01, -6.42787610e-01, 8.55211333e+00],
+                  [-3.42020143e-01, -9.39692621e-01, 9.77384381e+00],
+                  [-1.00000000e+00, -4.28626380e-16, 1.09955743e+01]]))
 
     assert_array_almost_equal(
         xyza2,
-        np.array([[  0.00000000e+00,   1.00000000e+00,   0.00000000e+00],
-                  [  9.95471923e-01,  -9.50560433e-02,   1.66599610e+00],
-                  [ -1.89251244e-01,  -9.81928697e-01,   3.33199221e+00],
-                  [ -9.59492974e-01,   2.81732557e-01,   4.99798831e+00],
-                  [  3.71662456e-01,   9.28367933e-01,   6.66398442e+00],
-                  [  8.88835449e-01,  -4.58226522e-01,   8.32998052e+00],
-                  [ -5.40640817e-01,  -8.41253533e-01,   9.99597663e+00],
-                  [ -1.00000000e+00,  -4.28626380e-16,   1.09955743e+01]]))
+        np.array([[0.00000000e+00, 1.00000000e+00, 0.00000000e+00],
+                  [9.95471923e-01, -9.50560433e-02, 1.66599610e+00],
+                  [-1.89251244e-01, -9.81928697e-01, 3.33199221e+00],
+                  [-9.59492974e-01, 2.81732557e-01, 4.99798831e+00],
+                  [3.71662456e-01, 9.28367933e-01, 6.66398442e+00],
+                  [8.88835449e-01, -4.58226522e-01, 8.32998052e+00],
+                  [-5.40640817e-01, -8.41253533e-01, 9.99597663e+00],
+                  [-1.00000000e+00, -4.28626380e-16, 1.09955743e+01]]))
 
 
 def test_point_track_sq_distance():
 
     t = np.array([[0, 0, 0], [1, 1, 1], [2, 2, 2]], dtype='f4')
     p = np.array([-1, -1., -1], dtype='f4')
-    assert_equal( pf.point_track_sq_distance_check(t, p, .2**2), False)
+    assert_equal(pf.point_track_sq_distance_check(t, p, .2**2), False)
     pf.point_track_sq_distance_check(t, p, 2**2), True
     t = np.array([[0, 0, 0], [1, 0, 0], [2, 2, 0]], dtype='f4')
     p = np.array([.5, 0, 0], dtype='f4')
-    assert_equal( pf.point_track_sq_distance_check(t, p, .2**2), True)
+    assert_equal(pf.point_track_sq_distance_check(t, p, .2**2), True)
     p = np.array([.5, 1, 0], dtype='f4')
-    assert_equal( pf.point_track_sq_distance_check(t, p, .2**2), False)
+    assert_equal(pf.point_track_sq_distance_check(t, p, .2**2), False)
 
 
 def test_track_roi_intersection_check():
     roi = np.array([[0, 0, 0], [1, 0, 0], [2, 0, 0]], dtype='f4')
     t = np.array([[0, 0, 0], [1, 1, 1], [2, 2, 2]], dtype='f4')
-    assert_equal( pf.track_roi_intersection_check(t, roi, 1), True)
+    assert_equal(pf.track_roi_intersection_check(t, roi, 1), True)
     t = np.array([[0, 0, 0], [1, 0, 0], [2, 2, 2]], dtype='f4')
     assert_equal(pf.track_roi_intersection_check(t, roi, 1), True)
     t = np.array([[1, 1, 0], [1, 0, 0], [1, -1, 0]], dtype='f4')
-    assert_equal( pf.track_roi_intersection_check(t, roi, 1), True)
+    assert_equal(pf.track_roi_intersection_check(t, roi, 1), True)
     t = np.array([[4, 0, 0], [4, 1, 1], [4, 2, 0]], dtype='f4')
     assert_equal(pf.track_roi_intersection_check(t, roi, 1), False)
 
@@ -276,14 +297,12 @@ def test_cut_plane():
                np.array([[0.5, 1, 1], [1.5, 2, 2], [2.5, 3, 3]], dtype=dt),
                np.array([[-0.5, 2, -1], [-1.5, 3, -2], [-2.5, 4, -3]],
                         dtype=dt)]
-    expected_hit0 = [
-        [ 1.        ,  1.5       ,  0.        ,  0.70710683,  0.        ],
-        [ 1.        ,  2.5       ,  0.        ,  0.70710677,  1.        ],
-        [ 1.        ,  1.5       ,  1.5       ,  0.81649661,  2.        ]]
-    expected_hit1 = [
-        [ 2.        ,  2.5       ,  0.        ,  0.70710677,  0.        ],
-        [ 2.        ,  3.5       ,  0.        ,  0.70710677,  1.        ],
-        [ 2.        ,  2.5       ,  2.5       ,  0.81649655,  2.        ]]
+    expected_hit0 = [[1., 1.5, 0., 0.70710683, 0.],
+                     [1., 2.5, 0., 0.70710677, 1.],
+                     [1., 1.5, 1.5, 0.81649661, 2.]]
+    expected_hit1 = [[2., 2.5, 0., 0.70710677, 0.],
+                     [2., 3.5, 0., 0.70710677, 1.],
+                     [2., 2.5, 2.5, 0.81649655, 2.]]
     hitx = pf.cut_plane(bundlex, refx)
     assert_array_almost_equal(hitx[0], expected_hit0)
     assert_array_almost_equal(hitx[1], expected_hit1)
