@@ -1,5 +1,5 @@
-from __future__ import print_function
 
+import warnings
 import types
 
 import numpy as np
@@ -8,12 +8,12 @@ import numpy.testing as npt
 from dipy.testing.memory import get_type_refcount
 from dipy.testing import assert_arrays_equal
 
-from nose.tools import assert_true, assert_equal, assert_almost_equal
+from dipy.testing import assert_true
 from numpy.testing import (assert_array_equal, assert_array_almost_equal,
-                           assert_raises, run_module_suite, assert_allclose)
+                           assert_raises, assert_allclose,
+                           assert_almost_equal, assert_equal)
 
 from dipy.tracking.streamline import Streamlines
-import dipy.tracking.utils as ut
 from dipy.tracking.streamline import (set_number_of_points,
                                       length,
                                       relist_streamlines,
@@ -24,8 +24,10 @@ from dipy.tracking.streamline import (set_number_of_points,
                                       compress_streamlines,
                                       select_by_rois,
                                       orient_by_rois,
+                                      orient_by_streamline,
                                       values_from_volume,
-                                      deform_streamlines)
+                                      deform_streamlines,
+                                      cluster_confidence)
 
 
 streamline = np.array([[82.20181274,  91.36505890,  43.15737152],
@@ -317,8 +319,8 @@ def test_set_number_of_points():
                  len(streamlines_readonly))
 
     # Test if nb_points is less than 2
-    assert_raises(ValueError, set_number_of_points, [np.ones((10, 3)),
-                  np.ones((10, 3))], nb_points=1)
+    assert_raises(ValueError, set_number_of_points, [
+                  np.ones((10, 3)), np.ones((10, 3))], nb_points=1)
 
 
 def test_set_number_of_points_memory_leaks():
@@ -540,21 +542,24 @@ def test_deform_streamlines():
 
     # Interpolate displacements onto original streamlines
     streamlines_in_grid = transform_streamlines(streamlines, stream2grid)
-    disps = values_from_volume(deformation_field, streamlines_in_grid)
+    disps = values_from_volume(deformation_field, streamlines_in_grid,
+                               np.eye(4))
 
     # Put new_streamlines into world space
     new_streamlines_world = transform_streamlines(new_streamlines,
                                                   stream2world)
 
     # Subtract disps from new_streamlines in world space
-    orig_streamlines_world = list(np.subtract(new_streamlines_world, disps))
+    orig_streamlines_world = np.subtract(np.array(new_streamlines_world,
+                                                  dtype=object),
+                                         np.array(disps, dtype=object))
 
     # Put orig_streamlines_world into voxmm
     orig_streamlines = transform_streamlines(orig_streamlines_world,
                                              np.linalg.inv(stream2world))
-    # All close because of floating pt inprecision
+    # All close because of floating pt imprecision
     for o, s in zip(orig_streamlines, streamlines):
-        assert_allclose(s, o, rtol=1e-10, atol=0)
+        assert_allclose(s, o, rtol=1e-6, atol=1e-6)
 
 
 def test_center_and_transform():
@@ -640,7 +645,7 @@ def compress_streamlines_python(streamline, tol_error=0.01,
 
 def test_compress_streamlines():
     for compress_func in [compress_streamlines_python, compress_streamlines]:
-        # Small streamlines (less than two points) are uncompressable.
+        # Small streamlines (less than two points) are incompressible.
         for small_streamline in [np.array([[]]),
                                  np.array([[1, 1, 1]]),
                                  np.array([[1, 1, 1], [2, 2, 2]])]:
@@ -678,7 +683,7 @@ def test_compress_streamlines():
         # (like the C++ version)
         compress_func(streamline, max_segment_length=np.inf)
 
-        # Uncompressable streamline when `tol_error` == 1.
+        # Incompressable streamline when `tol_error` == 1.
         simple_streamline = np.array([[0, 0, 0],
                                       [1, 1, 0],
                                       [1.5, np.inf, 0],
@@ -692,7 +697,7 @@ def test_compress_streamlines():
             assert_array_equal(c_streamline, simple_streamline)
 
     # Create a special streamline where every other point is increasingly
-    # farther from a straigth line formed by the streamline endpoints.
+    # farther from a straight line formed by the streamline endpoints.
     tol_errors = np.linspace(0, 10, 21)
     orthogonal_line = np.array([[-np.sqrt(2)/2, np.sqrt(2)/2, 0]],
                                dtype=np.float32)
@@ -720,9 +725,9 @@ def test_compress_streamlines():
 
         # Make sure Cython and Python versions are the same.
         cstreamline_python = compress_streamlines_python(
-                                            special_streamline,
-                                            tol_error=tol_error+1e-4,
-                                            max_segment_length=np.inf)
+            special_streamline,
+            tol_error=tol_error+1e-4,
+            max_segment_length=np.inf)
         assert_equal(len(cspecial_streamline), len(cstreamline_python))
         assert_array_almost_equal(cspecial_streamline, cstreamline_python)
 
@@ -796,68 +801,74 @@ def test_select_by_rois():
     mask1[0, 0, 0] = True
     mask2[1, 0, 0] = True
 
-    selection = select_by_rois(streamlines, [mask1], [True],
+    selection = select_by_rois(streamlines, np.eye(4), [mask1], [True],
                                tol=1)
 
     assert_arrays_equal(list(selection), [streamlines[0],
-                        streamlines[1]])
+                                          streamlines[1]])
 
-    selection = select_by_rois(streamlines, [mask1, mask2], [True, True],
-                               tol=1)
+    selection = select_by_rois(streamlines, np.eye(4), [mask1, mask2],
+                               [True, True], tol=1)
 
     assert_arrays_equal(list(selection), [streamlines[0],
-                        streamlines[1]])
+                                          streamlines[1]])
 
-    selection = select_by_rois(streamlines, [mask1, mask2], [True, False])
+    selection = select_by_rois(streamlines, np.eye(4), [
+                               mask1, mask2], [True, False])
 
     assert_arrays_equal(list(selection), [streamlines[1]])
 
     # Setting tolerance too low gets overridden:
-    selection = select_by_rois(streamlines, [mask1, mask2], [True, False],
-                               tol=0.1)
-    assert_arrays_equal(list(selection), [streamlines[1]])
+    with warnings.catch_warnings():
+        warnings.simplefilter("ignore")
+        selection = select_by_rois(streamlines, np.eye(4), [mask1, mask2],
+                                   [True, False], tol=0.1)
 
-    selection = select_by_rois(streamlines, [mask1, mask2], [True, True],
-                               tol=0.87)
+        assert_arrays_equal(list(selection), [streamlines[1]])
+
+    selection = select_by_rois(streamlines, np.eye(4), [mask1, mask2],
+                               [True, True], tol=0.87)
 
     assert_arrays_equal(list(selection), [streamlines[1]])
 
     mask3 = np.zeros_like(mask1)
     mask3[0, 2, 2] = 1
-    selection = select_by_rois(streamlines, [mask1, mask2, mask3],
+    selection = select_by_rois(streamlines, np.eye(4), [mask1, mask2, mask3],
                                [True, True, False], tol=1.0)
 
     assert_arrays_equal(list(selection), [streamlines[0]])
 
     # Select using only one ROI
-    selection = select_by_rois(streamlines, [mask1], [True], tol=0.87)
+    selection = select_by_rois(streamlines, np.eye(4), [
+                               mask1], [True], tol=0.87)
     assert_arrays_equal(list(selection), [streamlines[1]])
 
-    selection = select_by_rois(streamlines, [mask1], [True], tol=1.0)
+    selection = select_by_rois(streamlines, np.eye(4), [
+                               mask1], [True], tol=1.0)
     assert_arrays_equal(list(selection), [streamlines[0],
-                        streamlines[1]])
+                                          streamlines[1]])
 
     # Use different modes:
-    selection = select_by_rois(streamlines, [mask1, mask2, mask3],
+    selection = select_by_rois(streamlines, np.eye(4), [mask1, mask2, mask3],
                                [True, True, False],
                                mode="all",
                                tol=1.0)
     assert_arrays_equal(list(selection), [streamlines[0]])
 
-    selection = select_by_rois(streamlines, [mask1, mask2, mask3],
+    selection = select_by_rois(streamlines, np.eye(4), [mask1, mask2, mask3],
                                [True, True, False],
                                mode="either_end",
                                tol=1.0)
     assert_arrays_equal(list(selection), [streamlines[0]])
 
-    selection = select_by_rois(streamlines, [mask1, mask2, mask3],
+    selection = select_by_rois(streamlines, np.eye(4), [mask1, mask2, mask3],
                                [True, True, False],
                                mode="both_end",
                                tol=1.0)
     assert_arrays_equal(list(selection), [streamlines[0]])
 
     mask2[0, 2, 2] = True
-    selection = select_by_rois(streamlines, [mask1, mask2, mask3],
+    selection = select_by_rois(streamlines, np.eye(4), [mask1, mask2, mask3],
                                [True, True, False],
                                mode="both_end",
                                tol=1.0)
@@ -866,19 +877,19 @@ def test_select_by_rois():
                                           streamlines[1]])
 
     # Test with generator input:
-    selection = select_by_rois(generate_sl(streamlines), [mask1], [True],
-                               tol=1.0)
+    selection = select_by_rois(generate_sl(streamlines), np.eye(4), [mask1],
+                               [True], tol=1.0)
     assert_arrays_equal(list(selection), [streamlines[0],
-                        streamlines[1]])
+                                          streamlines[1]])
 
 
 def test_orient_by_rois():
-    streamlines = [np.array([[0, 0., 0],
-                             [1, 0., 0.],
-                             [2, 0., 0.]]),
-                   np.array([[2, 0., 0.],
-                             [1, 0., 0],
-                             [0, 0,  0.]])]
+    streamlines = Streamlines([np.array([[0, 0., 0],
+                                         [1, 0., 0.],
+                                         [2, 0., 0.]]),
+                               np.array([[2, 0., 0.],
+                                         [1, 0., 0],
+                                         [0, 0,  0.]])])
 
     # Make two ROIs:
     mask1_vol = np.zeros((4, 4, 4), dtype=bool)
@@ -892,103 +903,161 @@ def test_orient_by_rois():
     affine = np.eye(4)
     affine[:, 3] = [-1, 100, -20, 1]
     # Transform the streamlines:
-    x_streamlines = [sl + affine[:3, 3] for sl in streamlines]
+    x_streamlines = Streamlines([sl + affine[:3, 3] for sl in streamlines])
 
     # After reorientation, this should be the answer:
-    flipped_sl = [streamlines[0], streamlines[1][::-1]]
-    new_streamlines = orient_by_rois(streamlines,
+    flipped_sl = Streamlines([streamlines[0], streamlines[1][::-1]])
+    new_streamlines = orient_by_rois(streamlines, np.eye(4),
                                      mask1_vol,
                                      mask2_vol,
                                      in_place=False,
-                                     affine=None,
                                      as_generator=False)
-    npt.assert_equal(new_streamlines, flipped_sl)
+    npt.assert_array_equal(new_streamlines, flipped_sl)
+
     npt.assert_(new_streamlines is not streamlines)
 
     # Test with affine:
-    x_flipped_sl = [s + affine[:3, 3] for s in flipped_sl]
-    new_streamlines = orient_by_rois(x_streamlines,
+    x_flipped_sl = Streamlines([s + affine[:3, 3] for s in flipped_sl])
+    new_streamlines = orient_by_rois(x_streamlines, affine,
                                      mask1_vol,
                                      mask2_vol,
                                      in_place=False,
-                                     affine=affine,
                                      as_generator=False)
-    npt.assert_equal(new_streamlines, x_flipped_sl)
+    npt.assert_array_equal(new_streamlines, x_flipped_sl)
     npt.assert_(new_streamlines is not x_streamlines)
 
     # Test providing coord ROIs instead of vol ROIs:
-    new_streamlines = orient_by_rois(x_streamlines,
+    new_streamlines = orient_by_rois(x_streamlines, affine,
                                      mask1_coords,
                                      mask2_coords,
                                      in_place=False,
-                                     affine=affine,
                                      as_generator=False)
-    npt.assert_equal(new_streamlines, x_flipped_sl)
+    npt.assert_array_equal(new_streamlines, x_flipped_sl)
 
     # Test with as_generator set to True
-    new_streamlines = orient_by_rois(streamlines,
+    new_streamlines = orient_by_rois(streamlines, np.eye(4),
                                      mask1_vol,
                                      mask2_vol,
                                      in_place=False,
-                                     affine=None,
                                      as_generator=True)
 
     npt.assert_(isinstance(new_streamlines, types.GeneratorType))
-    ll = list(new_streamlines)
-    npt.assert_equal(ll, flipped_sl)
+    ll = Streamlines(new_streamlines)
+    npt.assert_array_equal(ll, flipped_sl)
 
     # Test with as_generator set to True and with the affine
-    new_streamlines = orient_by_rois(x_streamlines,
+    new_streamlines = orient_by_rois(x_streamlines, affine,
                                      mask1_vol,
                                      mask2_vol,
                                      in_place=False,
-                                     affine=affine,
                                      as_generator=True)
 
     npt.assert_(isinstance(new_streamlines, types.GeneratorType))
-    ll = list(new_streamlines)
-    npt.assert_equal(ll, x_flipped_sl)
+    ll = Streamlines(new_streamlines)
+    npt.assert_array_equal(ll, x_flipped_sl)
 
     # Test with generator input:
-    new_streamlines = orient_by_rois(generate_sl(streamlines),
+    new_streamlines = orient_by_rois(generate_sl(streamlines), np.eye(4),
                                      mask1_vol,
                                      mask2_vol,
                                      in_place=False,
-                                     affine=None,
                                      as_generator=True)
 
     npt.assert_(isinstance(new_streamlines, types.GeneratorType))
-    ll = list(new_streamlines)
-    npt.assert_equal(ll, flipped_sl)
+    ll = Streamlines(new_streamlines)
+    npt.assert_array_equal(ll, flipped_sl)
 
     # Generator output cannot take a True `in_place` kwarg:
     npt.assert_raises(ValueError, orient_by_rois, *[generate_sl(streamlines),
+                                                    np.eye(4),
                                                     mask1_vol,
                                                     mask2_vol],
                       **dict(in_place=True,
-                             affine=None,
                              as_generator=True))
 
     # But you can input a generator and get a non-generator as output:
-    new_streamlines = orient_by_rois(generate_sl(streamlines),
+    new_streamlines = orient_by_rois(generate_sl(streamlines), np.eye(4),
                                      mask1_vol,
                                      mask2_vol,
                                      in_place=False,
-                                     affine=None,
                                      as_generator=False)
 
     npt.assert_(not isinstance(new_streamlines, types.GeneratorType))
-    npt.assert_equal(new_streamlines, flipped_sl)
+    npt.assert_array_equal(new_streamlines, flipped_sl)
 
     # Modify in-place:
-    new_streamlines = orient_by_rois(streamlines,
+    new_streamlines = orient_by_rois(streamlines, np.eye(4),
                                      mask1_vol,
                                      mask2_vol,
                                      in_place=True,
-                                     affine=None,
                                      as_generator=False)
 
-    npt.assert_equal(new_streamlines, flipped_sl)
+    npt.assert_array_equal(new_streamlines, flipped_sl)
+    # The two objects are one and the same:
+    npt.assert_(new_streamlines is streamlines)
+
+
+def test_orient_by_streamline():
+    streamlines = Streamlines([np.array([[0, 0., 0],
+                                         [1, 0., 0.],
+                                         [2, 0., 0.]]),
+                               np.array([[2, 0., 0.],
+                                         [1, 0., 0],
+                                         [0, 0,  0.]])])
+
+    # If there is an affine, we'll use it:
+    affine = np.eye(4)
+    affine[:, 3] = [-1, 100, -20, 1]
+    # Transform the streamlines:
+    x_streamlines = Streamlines([sl + affine[:3, 3] for sl in streamlines])
+
+    standard_streamline = streamlines[0]
+
+    # After reorientation, this should be the answer:
+    flipped_sl = Streamlines([streamlines[0], streamlines[1][::-1]])
+
+    new_streamlines = orient_by_streamline(streamlines,
+                                           standard_streamline,
+                                           n_points=12,
+                                           in_place=False)
+
+    npt.assert_array_equal(new_streamlines, flipped_sl)
+    npt.assert_(new_streamlines is not streamlines)
+
+    # Test with affine:
+    x_flipped_sl = Streamlines([s + affine[:3, 3] for s in flipped_sl])
+    new_streamlines = orient_by_streamline(x_streamlines,
+                                           standard_streamline,
+                                           in_place=False)
+    npt.assert_array_equal(new_streamlines, x_flipped_sl)
+    npt.assert_(new_streamlines is not x_streamlines)
+
+    # Test with as_generator set to True
+    new_streamlines = orient_by_streamline(streamlines,
+                                           standard_streamline,
+                                           in_place=False,
+                                           as_generator=True)
+
+    npt.assert_(isinstance(new_streamlines, types.GeneratorType))
+    ll = Streamlines(new_streamlines)
+    npt.assert_array_equal(ll, flipped_sl)
+
+    # Test with as_generator set to True and with the affine
+    new_streamlines = orient_by_streamline(x_streamlines,
+                                           standard_streamline,
+                                           in_place=False,
+                                           as_generator=True)
+
+    npt.assert_(isinstance(new_streamlines, types.GeneratorType))
+    ll = Streamlines(new_streamlines)
+    npt.assert_array_equal(ll, x_flipped_sl)
+
+    # Modify in-place:
+    new_streamlines = orient_by_streamline(streamlines,
+                                           standard_streamline,
+                                           in_place=True)
+
+    npt.assert_array_equal(new_streamlines, flipped_sl)
     # The two objects are one and the same:
     npt.assert_(new_streamlines is streamlines)
 
@@ -1021,38 +1090,40 @@ def test_values_from_volume():
                      data[3, 0, 0] + (data[4, 0, 0] - data[3, 0, 0]) * 0.9,
                      data[4, 0, 0] + (data[5, 0, 0] - data[4, 0, 0]) * 0.1]]
 
-            vv = values_from_volume(data, sl1)
+            vv = values_from_volume(data, sl1, np.eye(4))
             npt.assert_almost_equal(vv, ans1, decimal=decimal)
 
-            vv = values_from_volume(data, np.array(sl1))
+            vv = values_from_volume(data, np.array(sl1), np.eye(4))
+            npt.assert_almost_equal(vv, ans1, decimal=decimal)
+
+            vv = values_from_volume(data, Streamlines(sl1), np.eye(4))
             npt.assert_almost_equal(vv, ans1, decimal=decimal)
 
             affine = np.eye(4)
             affine[:, 3] = [-100, 10, 1, 1]
-            x_sl1 = ut.move_streamlines(sl1, affine)
-            x_sl2 = ut.move_streamlines(sl1, affine)
+            x_sl1 = transform_streamlines(sl1, affine)
+            x_sl2 = transform_streamlines(sl1, affine)
 
-            vv = values_from_volume(data, x_sl1, affine=affine)
+            vv = values_from_volume(data, x_sl1, affine)
             npt.assert_almost_equal(vv, ans1, decimal=decimal)
 
-            # The generator has already been consumed so needs to be
-            # regenerated:
-            x_sl1 = list(ut.move_streamlines(sl1, affine))
-            vv = values_from_volume(data, x_sl1, affine=affine)
+            x_sl1 = transform_streamlines(sl1, affine)
+            vv = values_from_volume(data, x_sl1, affine)
+
             npt.assert_almost_equal(vv, ans1, decimal=decimal)
 
             # Test that the streamlines haven't mutated:
             l_sl2 = list(x_sl2)
             npt.assert_equal(x_sl1, l_sl2)
 
-            vv = values_from_volume(data, np.array(x_sl1), affine=affine)
+            vv = values_from_volume(data, np.array(x_sl1), affine)
             npt.assert_almost_equal(vv, ans1, decimal=decimal)
             npt.assert_equal(np.array(x_sl1), np.array(l_sl2))
 
             # Test for lists of streamlines with different numbers of nodes:
             sl2 = [sl1[0][:-1], sl1[1]]
             ans2 = [ans1[0][:-1], ans1[1]]
-            vv = values_from_volume(data, sl2)
+            vv = values_from_volume(data, sl2, np.eye(4))
             for ii, v in enumerate(vv):
                 npt.assert_almost_equal(v, ans2[ii], decimal=decimal)
 
@@ -1067,16 +1138,20 @@ def test_values_from_volume():
                              [3.9, 0, 0],
                              [4.1, 0, 0]]))
 
-    npt.assert_raises(RuntimeError, values_from_volume, data, nonsense_sl)
+    npt.assert_raises(RuntimeError, values_from_volume, data,
+                      nonsense_sl,
+                      np.eye(4))
 
     # For some use-cases we might have singleton streamlines (with only one
     # node each):
     data3D = np.ones((2, 2, 2))
     streamlines = np.ones((10, 1, 3))
-    npt.assert_equal(values_from_volume(data3D, streamlines).shape, (10, 1))
+    npt.assert_equal(values_from_volume(data3D, streamlines,
+                                        np.eye(4)).shape, (10, 1))
     data4D = np.ones((2, 2, 2, 2))
     streamlines = np.ones((10, 1, 3))
-    npt.assert_equal(values_from_volume(data4D, streamlines).shape, (10, 1, 2))
+    npt.assert_equal(values_from_volume(data4D, streamlines,
+                                        np.eye(4)).shape, (10, 1, 2))
 
 
 def test_streamlines_generator():
@@ -1088,12 +1163,106 @@ def test_streamlines_generator():
     npt.assert_equal(len(streamlines_generator), len(streamlines))
 
     # Test append error
-    npt.assert_raises(ValueError, streamlines_generator.append, streamlines)
+    npt.assert_raises(ValueError, streamlines_generator.append,
+                      np.array(streamlines, dtype=object))
 
     # Test empty streamlines
     streamlines_generator = Streamlines(np.array([]))
     npt.assert_equal(len(streamlines_generator), 0)
 
 
-if __name__ == '__main__':
-    npt.run_module_suite()
+def test_cluster_confidence():
+    mysl = np.array([np.arange(10)] * 3, 'float').T
+
+    # a short streamline (<20 mm) should raise an error unless override=True
+    test_streamlines = Streamlines()
+    test_streamlines.append(mysl)
+    assert_raises(ValueError, cluster_confidence, test_streamlines)
+    cci = cluster_confidence(test_streamlines, override=True)
+
+    # two identical streamlines should raise an error
+    test_streamlines = Streamlines()
+    test_streamlines.append(mysl, cache_build=True)
+    test_streamlines.append(mysl)
+    test_streamlines.finalize_append()
+    assert_raises(ValueError, cluster_confidence, test_streamlines)
+
+    # 3 offset collinear streamlines
+    test_streamlines = Streamlines()
+    test_streamlines.append(mysl, cache_build=True)
+    test_streamlines.append(mysl+1)
+    test_streamlines.append(mysl+2)
+    test_streamlines.finalize_append()
+    with warnings.catch_warnings(record=True) as w:
+        cci = cluster_confidence(test_streamlines, override=True)
+        assert_true("do not have the same number of points" in
+                    str(w[0].message))
+    assert_equal(cci[0], cci[2])
+    assert_true(cci[1] > cci[0])
+
+    # 3 parallel streamlines
+    mysl = np.zeros([10, 3])
+    mysl[:, 0] = np.arange(10)
+    mysl2 = mysl.copy()
+    mysl2[:, 1] = 1
+    mysl3 = mysl.copy()
+    mysl3[:, 1] = 2
+    mysl4 = mysl.copy()
+    mysl4[:, 1] = 4
+    mysl5 = mysl.copy()
+    mysl5[:, 1] = 5000
+
+    test_streamlines_p1 = Streamlines()
+    test_streamlines_p1.append(mysl, cache_build=True)
+    test_streamlines_p1.append(mysl2)
+    test_streamlines_p1.append(mysl3)
+    test_streamlines_p1.finalize_append()
+    test_streamlines_p2 = Streamlines()
+    test_streamlines_p2.append(mysl, cache_build=True)
+    test_streamlines_p2.append(mysl3)
+    test_streamlines_p2.append(mysl4)
+    test_streamlines_p2.finalize_append()
+    test_streamlines_p3 = Streamlines()
+    test_streamlines_p3.append(mysl, cache_build=True)
+    test_streamlines_p3.append(mysl2)
+    test_streamlines_p3.append(mysl3)
+    test_streamlines_p3.append(mysl5)
+    test_streamlines_p3.finalize_append()
+
+    with warnings.catch_warnings(record=True) as w:
+        cci_p1 = cluster_confidence(test_streamlines_p1, override=True)
+        cci_p2 = cluster_confidence(test_streamlines_p2, override=True)
+        assert_true("do not have the same number of points" in
+                    str(w[0].message))
+
+    # test relative distance
+    assert_array_equal(cci_p1, cci_p2*2)
+
+    # test simple cci calculation
+    expected_p1 = np.array([1./1+1./2, 1./1+1./1, 1./1+1./2])
+    expected_p2 = np.array([1./2+1./4, 1./2+1./2, 1./2+1./4])
+    assert_array_equal(expected_p1, cci_p1)
+    assert_array_equal(expected_p2, cci_p2)
+
+    # test power variable calculation (dropoff with distance)
+    with warnings.catch_warnings(record=True) as w:
+        cci_p1_pow2 = cluster_confidence(test_streamlines_p1, power=2,
+                                         override=True)
+        assert_true("do not have the same number of points" in
+                    str(w[0].message))
+
+    expected_p1_pow2 = np.array([np.power(1./1, 2)+np.power(1./2, 2),
+                                 np.power(1./1, 2)+np.power(1./1, 2),
+                                 np.power(1./1, 2)+np.power(1./2, 2)])
+
+    assert_array_equal(cci_p1_pow2, expected_p1_pow2)
+
+    with warnings.catch_warnings(record=True) as w:
+        # test max distance (ignore distant sls)
+        cci_dist = cluster_confidence(test_streamlines_p3,
+                                      max_mdf=5, override=True)
+        assert_true("do not have the same number of points" in
+                    str(w[0].message))
+
+    expected_cci_dist = np.concatenate([cci_p1, np.zeros(1)])
+    assert_array_equal(cci_dist, expected_cci_dist)
