@@ -5,9 +5,7 @@ import os
 from dipy.utils.omp import (cpu_count, thread_count, default_threads,
                             _set_omp_threads, _restore_omp_threads,
                             have_openmp)
-
-from nose.tools import assert_equal
-from numpy.testing import run_module_suite
+from numpy.testing import assert_equal, run_module_suite
 
 
 def test_set_omp_threads():
