@@ -1,7 +1,5 @@
 #!/usr/bin/env python
-from __future__ import division
 
-import inspect
 import logging
 import numpy as np
 
@@ -25,7 +23,7 @@ class MaskFlow(Workflow):
            Path to image to be masked.
         lb : float
             Lower bound value.
-        ub : float
+        ub : float, optional
             Upper bound value (default Inf)
         out_dir : string, optional
            Output directory (default input file directory)
