@@ -10,7 +10,7 @@ To show the concept we will use two pre-saved cingulum bundles. The algorithm
 used here is called Streamline-based Linear Registration (SLR) [Garyfallidis15]_.
 """
 
-from dipy.viz import fvtk
+from dipy.viz import window, actor
 from time import sleep
 from dipy.data import two_cingulum_bundles
 
@@ -24,7 +24,7 @@ from dipy.tracking.streamline import set_number_of_points
 An important step before running the registration is to resample the
 streamlines so that they both have the same number of points per streamline.
 Here we will use 20 points. This step is not optional. Inputting streamlines
-with different number of points will break the theoretical advantages of using
+with a different number of points will break the theoretical advantages of using
 the SLR as explained in [Garyfallidis15]_.
 """
 
@@ -48,25 +48,26 @@ After the optimization is finished we can apply the transformation to
 cb_subj2_aligned = srm.transform(cb_subj2)
 
 
-def show_both_bundles(bundles, colors=None, show=False, fname=None):
+def show_both_bundles(bundles, colors=None, show=True, fname=None):
 
-    ren = fvtk.ren()
-    ren.SetBackground(1., 1, 1)
+    scene = window.Scene()
+    scene.SetBackground(1., 1, 1)
     for (i, bundle) in enumerate(bundles):
         color = colors[i]
-        lines = fvtk.streamtube(bundle, color, linewidth=0.3)
-        lines.RotateX(-90)
-        lines.RotateZ(90)
-        fvtk.add(ren, lines)
+        lines_actor = actor.streamtube(bundle, color, linewidth=0.3)
+        lines_actor.RotateX(-90)
+        lines_actor.RotateZ(90)
+        scene.add(lines_actor)
     if show:
-        fvtk.show(ren)
+        window.show(scene)
     if fname is not None:
         sleep(1)
-        fvtk.record(ren, n_frames=1, out_path=fname, size=(900, 900))
+        window.record(scene, n_frames=1, out_path=fname, size=(900, 900))
 
 
 show_both_bundles([cb_subj1, cb_subj2],
-                  colors=[fvtk.colors.orange, fvtk.colors.red],
+                  colors=[window.colors.orange, window.colors.red],
+                  show=False,
                   fname='before_registration.png')
 
 """
@@ -77,7 +78,8 @@ show_both_bundles([cb_subj1, cb_subj2],
 """
 
 show_both_bundles([cb_subj1, cb_subj2_aligned],
-                  colors=[fvtk.colors.orange, fvtk.colors.red],
+                  colors=[window.colors.orange, window.colors.red],
+                  show=False,
                   fname='after_registration.png')
 
 """
@@ -87,12 +89,12 @@ show_both_bundles([cb_subj1, cb_subj2_aligned],
    After bundle registration.
 
 As you can see the two cingulum bundles are well aligned although they contain
-many streamlines of different length and shape.
+many streamlines of different lengths and shapes.
 
-.. [Garyfallidis15] Garyfallidis et. al, "Robust and efficient linear
+.. [Garyfallidis15] Garyfallidis et al., "Robust and efficient linear
                     registration of white-matter fascicles in the space
                     of streamlines", Neuroimage, 117:124-140, 2015.
-.. [Garyfallidis14] Garyfallidis et. al, "Direct native-space fiber bundle
+.. [Garyfallidis14] Garyfallidis et al., "Direct native-space fiber bundle
                     alignment for group comparisons", ISMRM, 2014.
 
 """
