@@ -1,12 +1,12 @@
 """
-=================================================
+=================================
 Linear fascicle evaluation (LiFE)
-=================================================
+=================================
 
 Evaluating the results of tractography algorithms is one of the biggest
 challenges for diffusion MRI. One proposal for evaluation of tractography
-results is to use a forward model that predicts the signal from each of a set of
-streamlines, and then fit a linear model to these simultaneous predictions
+results is to use a forward model that predicts the signal from each of a set
+of streamlines, and then fit a linear model to these simultaneous predictions
 [Pestilli2014]_.
 
 We will use streamlines generated using probabilistic tracking on CSA
@@ -20,64 +20,82 @@ created in that example:
 
 """
 
+from mpl_toolkits.axes_grid1 import AxesGrid
+import matplotlib
+import matplotlib.pyplot as plt
+import dipy.tracking.life as life
+from dipy.viz import window, actor, colormap as cmap
 import numpy as np
 import os.path as op
-import nibabel as nib
+from dipy.io.streamline import load_trk
 import dipy.core.optimize as opt
 if not op.exists('lr-superiorfrontal.trk'):
     from streamline_tools import *
 else:
     # We'll need to know where the corpus callosum is from these variables:
-    from dipy.data import (read_stanford_labels,
-                           fetch_stanford_t1,
-                           read_stanford_t1)
-    hardi_img, gtab, labels_img = read_stanford_labels()
-    labels = labels_img.get_data()
+    from dipy.core.gradients import gradient_table
+    from dipy.data import get_fnames
+    from dipy.io.gradients import read_bvals_bvecs
+    from dipy.io.image import load_nifti_data, load_nifti
+
+    hardi_fname, hardi_bval_fname, hardi_bvec_fname = get_fnames('stanford_hardi')
+    label_fname = get_fnames('stanford_labels')
+    t1_fname = get_fnames('stanford_t1')
+
+    data, affine, hardi_img = load_nifti(hardi_fname, return_img=True)
+    labels = load_nifti_data(label_fname)
+    t1_data = load_nifti_data(t1_fname)
+    bvals, bvecs = read_bvals_bvecs(hardi_bval_fname, hardi_bvec_fname)
+    gtab = gradient_table(bvals, bvecs)
+
     cc_slice = labels == 2
-    fetch_stanford_t1()
-    t1 = read_stanford_t1()
-    t1_data = t1.get_data()
-    data = hardi_img.get_data()
+
 # Read the candidates from file in voxel space:
-candidate_sl = [s[0] for s in nib.trackvis.read('lr-superiorfrontal.trk',
-                                                  points_space='voxel')[0]]
+candidate_sl_sft = load_trk('lr-superiorfrontal.trk', 'same')
+candidate_sl_sft.to_vox()
+candidate_sl = candidate_sl_sft.streamlines
 
 """
 
 The streamlines that are entered into the model are termed 'candidate
-streamliness' (or a 'candidate connectome'):
+streamlines' (or a 'candidate connectome'):
 
 """
 
 
 """
 
-Let's visualize the initial candidate group of streamlines in 3D, relative to the
-anatomical structure of this brain:
+Let's visualize the initial candidate group of streamlines in 3D, relative to
+the anatomical structure of this brain:
 
 """
 
-from dipy.viz.colormap import line_colors
-from dipy.viz import fvtk
-candidate_streamlines_actor = fvtk.streamtube(candidate_sl,
-                                       line_colors(candidate_sl))
-cc_ROI_actor = fvtk.contour(cc_slice, levels=[1], colors=[(1., 1., 0.)],
-                            opacities=[1.])
 
-vol_actor = fvtk.slicer(t1_data)
+# Enables/disables interactive visualization
+interactive = False
 
-vol_actor.display(40, None, None)
+candidate_streamlines_actor = actor.streamtube(candidate_sl,
+                                               cmap.line_colors(candidate_sl))
+cc_ROI_actor = actor.contour_from_roi(cc_slice, color=(1., 1., 0.),
+                                      opacity=0.5)
+
+vol_actor = actor.slicer(t1_data)
+
+vol_actor.display(x=40)
 vol_actor2 = vol_actor.copy()
-vol_actor2.display(None, None, 35)
+vol_actor2.display(z=35)
 
 # Add display objects to canvas
-ren = fvtk.ren()
-fvtk.add(ren, candidate_streamlines_actor)
-fvtk.add(ren, cc_ROI_actor)
-fvtk.add(ren, vol_actor)
-fvtk.add(ren, vol_actor2)
-fvtk.record(ren, n_frames=1, out_path='life_candidates.png',
-            size=(800, 800))
+scene = window.Scene()
+scene.add(candidate_streamlines_actor)
+scene.add(cc_ROI_actor)
+scene.add(vol_actor)
+scene.add(vol_actor2)
+window.record(scene, n_frames=1,
+              out_path='life_candidates.png',
+              size=(800, 800))
+if interactive:
+    window.show(scene)
 
 """
 
@@ -96,20 +114,19 @@ which contains the classes and functions that implement the model:
 
 """
 
-import dipy.tracking.life as life
 fiber_model = life.FiberModel(gtab)
 
 """
 
-Since we read the streamlines from a file, already in the voxel space, we do not
-need to transform them into this space. Otherwise, if the streamline coordinates
-were in the world space (relative to the scanner iso-center, or relative to the
-mid-point of the AC-PC-connecting line), we would use this::
+Since we read the streamlines from a file, already in the voxel space, we do
+not need to transform them into this space. Otherwise, if the streamline
+coordinates were in the world space (relative to the scanner iso-center, or
+relative to the mid-point of the AC-PC-connecting line), we would use this::
 
    inv_affine = np.linalg.inv(hardi_img.affine)
 
-the inverse transformation from world space to the voxel space as the affine for
-the following model fit.
+the inverse transformation from world space to the voxel space as the affine
+for the following model fit.
 
 The next step is to fit the model, producing a ``FiberFit`` class instance,
 that stores the data, as well as the results of the fitting procedure.
@@ -130,8 +147,8 @@ $i^{th}$ streamline (arbitrarily ordered) to each of the voxels. $X$ is a
 sparse matrix, because each streamline traverses only a small percentage of the
 voxels. The  expected contributions of the streamline are calculated using a
 forward model, where each node of the streamline is modeled as a cylindrical
-fiber compartment with Gaussian diffusion, using the diffusion tensor model. See
-[Pestilli2014]_ for more detail on the model, and variations of this model.
+fiber compartment with Gaussian diffusion, using the diffusion tensor model.
+See [Pestilli2014]_ for more detail on the model, and variations of this model.
 
 """
 
@@ -146,8 +163,6 @@ streamlines, and these streamlines will have $\beta_i$ that are 0.
 
 """
 
-import matplotlib.pyplot as plt
-import matplotlib
 fig, ax = plt.subplots(1)
 ax.hist(fiber_fit.beta, bins=100, histtype='step')
 ax.set_xlabel('Fiber weights')
@@ -171,13 +186,15 @@ optimized group of streamlines:
 
 """
 
-optimized_sl = list(np.array(candidate_sl)[np.where(fiber_fit.beta>0)[0]])
-ren = fvtk.ren()
-fvtk.add(ren, fvtk.streamtube(optimized_sl, line_colors(optimized_sl)))
-fvtk.add(ren, cc_ROI_actor)
-fvtk.add(ren, vol_actor)
-fvtk.record(ren, n_frames=1, out_path='life_optimized.png',
-            size=(800, 800))
+optimized_sl = list(np.array(candidate_sl)[np.where(fiber_fit.beta > 0)[0]])
+scene = window.Scene()
+scene.add(actor.streamtube(optimized_sl, cmap.line_colors(optimized_sl)))
+scene.add(cc_ROI_actor)
+scene.add(vol_actor)
+window.record(scene, n_frames=1, out_path='life_optimized.png',
+              size=(800, 800))
+if interactive:
+    window.show(scene)
 
 """
 
@@ -196,9 +213,9 @@ streamlines have presumably been removed (in this case, about 50% of the
 streamlines).
 
 But how well does the model do in explaining the diffusion data? We can
-quantify that: the ``FiberFit`` class instance has a `predict` method, which can
-be used to invert the model and predict back either the data that was used to
-fit the model, or other unseen data (e.g. in cross-validation, see
+quantify that: the ``FiberFit`` class instance has a `predict` method, which
+can be used to invert the model and predict back either the data that was used
+to fit the model, or other unseen data (e.g. in cross-validation, see
 :ref:`kfold_xval`).
 
 Without arguments, the ``.predict()`` method will predict the diffusion signal
@@ -231,8 +248,8 @@ voxel.
 
 beta_baseline = np.zeros(fiber_fit.beta.shape[0])
 pred_weighted = np.reshape(opt.spdot(fiber_fit.life_matrix, beta_baseline),
-                                     (fiber_fit.vox_coords.shape[0],
-                                      np.sum(~gtab.b0s_mask)))
+                           (fiber_fit.vox_coords.shape[0],
+                            np.sum(~gtab.b0s_mask)))
 mean_pred = np.empty((fiber_fit.vox_coords.shape[0], gtab.bvals.shape[0]))
 S0 = fiber_fit.b0_signal
 
@@ -245,7 +262,7 @@ to add back the mean and then multiply by S0 in every voxel:
 
 mean_pred[..., gtab.b0s_mask] = S0[:, None]
 mean_pred[..., ~gtab.b0s_mask] =\
-        (pred_weighted + fiber_fit.mean_signal[:, None]) * S0[:, None]
+    (pred_weighted + fiber_fit.mean_signal[:, None]) * S0[:, None]
 mean_error = mean_pred - fiber_fit.data
 mean_rmse = np.sqrt(np.mean(mean_error ** 2, -1))
 
@@ -261,12 +278,14 @@ without the model fit.
 
 fig, ax = plt.subplots(1)
 ax.hist(mean_rmse - model_rmse, bins=100, histtype='step')
-ax.text(0.2, 0.9,'Median RMSE, mean model: %.2f' % np.median(mean_rmse),
-     horizontalalignment='left',
-     verticalalignment='center', transform=ax.transAxes)
-ax.text(0.2, 0.8,'Median RMSE, LiFE: %.2f' % np.median(model_rmse),
-     horizontalalignment='left',
-     verticalalignment='center', transform=ax.transAxes)
+ax.text(0.2, 0.9, 'Median RMSE, mean model: %.2f' % np.median(mean_rmse),
+        horizontalalignment='left',
+        verticalalignment='center',
+        transform=ax.transAxes)
+ax.text(0.2, 0.8, 'Median RMSE, LiFE: %.2f' % np.median(model_rmse),
+        horizontalalignment='left',
+        verticalalignment='center',
+        transform=ax.transAxes)
 ax.set_xlabel('RMS Error')
 ax.set_ylabel('# voxels')
 fig.savefig('error_histograms.png')
@@ -301,13 +320,12 @@ vol_improve[fiber_fit.vox_coords[:, 0],
             fiber_fit.vox_coords[:, 1],
             fiber_fit.vox_coords[:, 2]] = mean_rmse - model_rmse
 sl_idx = 49
-from mpl_toolkits.axes_grid1 import AxesGrid
 fig = plt.figure()
 fig.subplots_adjust(left=0.05, right=0.95)
 ax = AxesGrid(fig, 111,
-              nrows_ncols = (1, 3),
-              label_mode = "1",
-              share_all = True,
+              nrows_ncols=(1, 3),
+              label_mode="1",
+              share_all=True,
               cbar_location="top",
               cbar_mode="each",
               cbar_size="10%",
@@ -319,7 +337,8 @@ ax[1].matshow(np.rot90(t1_data[sl_idx, :, :]), cmap=matplotlib.cm.bone)
 im = ax[1].matshow(np.rot90(vol_mean[sl_idx, :, :]), cmap=matplotlib.cm.hot)
 ax.cbar_axes[1].colorbar(im)
 ax[2].matshow(np.rot90(t1_data[sl_idx, :, :]), cmap=matplotlib.cm.bone)
-im = ax[2].matshow(np.rot90(vol_improve[sl_idx, :, :]), cmap=matplotlib.cm.RdBu)
+im = ax[2].matshow(np.rot90(vol_improve[sl_idx, :, :]),
+                   cmap=matplotlib.cm.RdBu)
 ax.cbar_axes[2].colorbar(im)
 for lax in ax:
     lax.set_xticks([])
