@@ -9,42 +9,39 @@ diffusion MRI datasets of Cartesian keyhole diffusion gradients.
 First import the necessary modules:
 """
 
-from dipy.data import fetch_taiwan_ntu_dsi, read_taiwan_ntu_dsi, get_sphere
+import numpy as np
+from dipy.core.gradients import gradient_table
+from dipy.data import get_fnames, get_sphere
+from dipy.io.gradients import read_bvals_bvecs
+from dipy.io.image import load_nifti
 from dipy.reconst.dsi import DiffusionSpectrumModel
 
 """
-Download and read the data for this tutorial.
+Download and get the data filenames for this tutorial.
 """
 
-fetch_taiwan_ntu_dsi()
-img, gtab = read_taiwan_ntu_dsi()
+fraw, fbval, fbvec = get_fnames('taiwan_ntu_dsi')
 
 """
-img contains a nibabel Nifti1Image object (data) and gtab contains a GradientTable
-object (gradient information e.g. b-values). For example to read the b-values
-it is possible to write print(gtab.bvals).
+img contains a nibabel Nifti1Image object (data) and gtab contains a
+GradientTable object (gradient information e.g. b-values). For example to read
+the b-values it is possible to write print(gtab.bvals).
 
 Load the raw diffusion data and the affine.
 """
 
-data = img.get_data()
+data, affine, voxel_size = load_nifti(fraw, return_voxsize=True)
+bvals, bvecs = read_bvals_bvecs(fbval, fbvec)
+bvecs[1:] = (bvecs[1:] /
+                 np.sqrt(np.sum(bvecs[1:] * bvecs[1:], axis=1))[:, None])
+gtab = gradient_table(bvals, bvecs)
 print('data.shape (%d, %d, %d, %d)' % data.shape)
 
 """
 data.shape ``(96, 96, 60, 203)``
 
 This dataset has anisotropic voxel sizes, therefore reslicing is necessary.
-"""
 
-affine = img.get_affine()
-
-"""
-Read the voxel size from the image header.
-"""
-
-voxel_size = img.get_header().get_zooms()[:3]
-
-"""
 Instantiate the Model and apply it to the data.
 """
 
@@ -54,7 +51,7 @@ dsmodel = DiffusionSpectrumModel(gtab)
 Lets just use one slice only from the data.
 """
 
-dataslice = data[:, :, data.shape[2] / 2]
+dataslice = data[:, :, data.shape[2] // 2]
 
 dsfit = dsmodel.fit(dataslice)
 
@@ -62,7 +59,7 @@ dsfit = dsmodel.fit(dataslice)
 Load an odf reconstruction sphere
 """
 
-sphere = get_sphere('symmetric724')
+sphere = get_sphere('repulsion724')
 
 """
 Calculate the ODFs with this specific sphere
@@ -101,12 +98,12 @@ for index in ndindex(dataslice.shape[:2]):
 
 """
 If you really want to save the PDFs of a full dataset on the disc we recommend
-using memory maps (``numpy.memmap``) but still have in mind that even if you do 
-that for example for a dataset of volume size ``(96, 96, 60)`` you will need about 
-2.5 GBytes which can take less space when reasonable spheres (with < 1000 vertices) 
-are used.
+using memory maps (``numpy.memmap``) but still have in mind that even if you do
+that for example for a dataset of volume size ``(96, 96, 60)`` you will need
+about 2.5 GBytes which can take less space when reasonable spheres
+(with < 1000 vertices) are used.
 
-Let's now calculate a map of Generalized Fractional Anisotropy (GFA) [Tuch04]_ 
+Let's now calculate a map of Generalized Fractional Anisotropy (GFA) [Tuch04]_
 using the DSI ODFs.
 """
 
@@ -125,15 +122,15 @@ plt.savefig('dsi_gfa.png', bbox_inches='tight', origin='lower', cmap='gray')
 .. figure:: dsi_gfa.png
    :align: center
 
-See also :ref:`example_reconst_dsi_metrics` for calculating different types 
+See also :ref:`example_reconst_dsi_metrics` for calculating different types
 of DSI maps.
 
 
-.. [Wedeen08] Wedeen et al., Diffusion spectrum magnetic resonance imaging (DSI) 
-            tractography of crossing fibers, Neuroimage, vol 41, no 4, 
-            1267-1277, 2008.
+.. [Wedeen08] Wedeen et al., Diffusion spectrum magnetic resonance imaging
+              (DSI) tractography of crossing fibers, Neuroimage, vol 41, no 4,
+              1267-1277, 2008.
 
-.. [Tuch04] Tuch, D.S, Q-ball imaging, MRM, vol 52, no 6, 1358-1372, 2004. 
+.. [Tuch04] Tuch, D.S, Q-ball imaging, MRM, vol 52, no 6, 1358-1372, 2004.
 
 .. include:: ../links_names.inc
 
