@@ -23,8 +23,9 @@ Where $\mathbf{g}$ is a unit vector in 3 space indicating the direction of
 measurement and b are the parameters of measurement, such as the strength and
 duration of diffusion-weighting gradient. $S(\mathbf{g}, b)$ is the
 diffusion-weighted signal measured and $S_0$ is the signal conducted in a
-measurement with no diffusion weighting. $\mathbf{D}$ is a positive-definite quadratic
-form, which contains six free parameters to be fit. These six parameters are:
+measurement with no diffusion weighting. $\mathbf{D}$ is a positive-definite
+quadratic form, which contains six free parameters to be fit. These six
+parameters are:
 
 .. math::
 
@@ -50,10 +51,13 @@ First import the necessary modules:
 import numpy as np
 
 """
-``nibabel`` is for loading imaging datasets
+``dipy.io.image`` is for loading / saving imaging datasets
+``dipy.io.gradients`` is for loading / saving our bvals and bvecs
 """
 
-import nibabel as nib
+from dipy.io.image import load_nifti, save_nifti
+from dipy.io.gradients import read_bvals_bvecs
+from dipy.core.gradients import gradient_table
 
 """
 ``dipy.reconst`` is for the reconstruction algorithms which we use to create
@@ -66,30 +70,26 @@ import dipy.reconst.dti as dti
 ``dipy.data`` is used for small datasets that we use in tests and examples.
 """
 
-from dipy.data import fetch_stanford_hardi
+from dipy.data import get_fnames
 
 """
-Fetch will download the raw dMRI dataset of a single subject. The size of the
-dataset is 87 MBytes. You only need to fetch once.
+``get_fnames`` will download the raw dMRI dataset of a single subject.
+The size of the dataset is 87 MBytes. You only need to fetch once. It
+will return the file names of our data.
 """
 
-fetch_stanford_hardi()
+hardi_fname, hardi_bval_fname, hardi_bvec_fname = get_fnames('stanford_hardi')
 
 """
-Next, we read the saved dataset
+Next, we read the saved dataset. gtab contains a ``GradientTable``
+object (information about the gradients e.g. b-values and b-vectors).
 """
 
-from dipy.data import read_stanford_hardi
+data, affine = load_nifti(hardi_fname)
 
-img, gtab = read_stanford_hardi()
+bvals, bvecs = read_bvals_bvecs(hardi_bval_fname, hardi_bvec_fname)
+gtab = gradient_table(bvals, bvecs)
 
-"""
-``img`` contains a nibabel Nifti1Image object (with the data) and gtab contains a
-``GradientTable`` object (information about the gradients e.g. b-values and
-b-vectors).
-"""
-
-data = img.get_data()
 print('data.shape (%d, %d, %d, %d)' % data.shape)
 
 """
@@ -102,8 +102,8 @@ calculating Tensors on the background of the image. This is done using DIPY_'s
 
 from dipy.segment.mask import median_otsu
 
-maskdata, mask = median_otsu(data, 3, 1, True,
-                             vol_idx=range(10, 50), dilate=2)
+maskdata, mask = median_otsu(data, vol_idx=range(10, 50), median_radius=3,
+                             numpass=1, autocrop=True, dilate=2)
 print('maskdata.shape (%d, %d, %d, %d)' % maskdata.shape)
 
 """
@@ -123,10 +123,10 @@ TensorModel in the following way:
 tenfit = tenmodel.fit(maskdata)
 
 """
-The fit method creates a ``TensorFit`` object which contains the fitting parameters
-and other attributes of the model. For example we can generate fractional
-anisotropy (FA) from the eigen-values of the tensor. FA is used to characterize
-the degree to which the distribution of diffusion in a voxel is
+The fit method creates a ``TensorFit`` object which contains the fitting
+parameters and other attributes of the model. For example we can generate
+fractional anisotropy (FA) from the eigen-values of the tensor. FA is used to
+characterize the degree to which the distribution of diffusion in a voxel is
 directional. That is, whether there is relatively unrestricted diffusion in one
 particular direction.
 
@@ -140,10 +140,10 @@ the tensor:
                     \lambda_2^2+\lambda_3^2}}
 
 Note that FA should be interpreted carefully. It may be an indication of the
-density of packing of fibers in a voxel, and the amount of myelin wrapping these
-axons, but it is not always a measure of "tissue integrity". For example, FA
-may decrease in locations in which there is fanning of white matter fibers, or
-where more than one population of white matter fibers crosses.
+density of packing of fibers in a voxel, and the amount of myelin wrapping
+these axons, but it is not always a measure of "tissue integrity". For example,
+FA may decrease in locations in which there is fanning of white matter fibers,
+or where more than one population of white matter fibers crosses.
 """
 
 print('Computing anisotropy measures (FA, MD, RGB)')
@@ -165,22 +165,20 @@ affine matrix which transform the image's coordinates to the world coordinates.
 Here, we choose to save the FA in ``float32``.
 """
 
-fa_img = nib.Nifti1Image(FA.astype(np.float32), img.affine)
-nib.save(fa_img, 'tensor_fa.nii.gz')
+save_nifti('tensor_fa.nii.gz', FA.astype(np.float32), affine)
 
 """
 You can now see the result with any nifti viewer or check it slice by slice
-using matplotlib_'s ``imshow``. In the same way you can save the eigen values, the
-eigen vectors or any other properties of the tensor.
+using matplotlib_'s ``imshow``. In the same way you can save the eigen values,
+the eigen vectors or any other properties of the tensor.
 """
 
-evecs_img = nib.Nifti1Image(tenfit.evecs.astype(np.float32), img.affine)
-nib.save(evecs_img, 'tensor_evecs.nii.gz')
+save_nifti('tensor_evecs.nii.gz', tenfit.evecs.astype(np.float32), affine)
 
 """
-Other tensor statistics can be calculated from the ``tenfit`` object. For example,
-a commonly calculated statistic is the mean diffusivity (MD). This is simply the
-mean of the  eigenvalues of the tensor. Since FA is a normalized
+Other tensor statistics can be calculated from the ``tenfit`` object. For
+example, a commonly calculated statistic is the mean diffusivity (MD). This is
+simply the mean of the  eigenvalues of the tensor. Since FA is a normalized
 measure of variance and MD is the mean, they are often used as complimentary
 measures. In DIPY, there are two equivalent ways to calculate the mean
 diffusivity. One is by calling the ``mean_diffusivity`` module function on the
@@ -188,7 +186,7 @@ eigen-values of the ``TensorFit`` class instance:
 """
 
 MD1 = dti.mean_diffusivity(tenfit.evals)
-nib.save(nib.Nifti1Image(MD1.astype(np.float32), img.affine), 'tensors_md.nii.gz')
+save_nifti('tensors_md.nii.gz', MD1.astype(np.float32), affine)
 
 """
 The other is to call the ``TensorFit`` class method:
@@ -199,13 +197,13 @@ MD2 = tenfit.md
 """
 Obviously, the quantities are identical.
 
-We can also compute the colored FA or RGB-map [Pajevic1999]_. First, we make sure
-that the FA is scaled between 0 and 1, we compute the RGB map and save it.
+We can also compute the colored FA or RGB-map [Pajevic1999]_. First, we make
+sure that the FA is scaled between 0 and 1, we compute the RGB map and save it.
 """
 
 FA = np.clip(FA, 0, 1)
 RGB = color_fa(FA, tenfit.evecs)
-nib.save(nib.Nifti1Image(np.array(255 * RGB, 'uint8'), img.affine), 'tensor_rgb.nii.gz')
+save_nifti('tensor_rgb.nii.gz', np.array(255 * RGB, 'uint8'), affine)
 
 """
 Let's try to visualize the tensor ellipsoids of a small rectangular
@@ -215,14 +213,14 @@ area in an axial slice of the splenium of the corpus callosum (CC).
 print('Computing tensor ellipsoids in a part of the splenium of the CC')
 
 from dipy.data import get_sphere
-sphere = get_sphere('symmetric724')
+sphere = get_sphere('repulsion724')
 
 from dipy.viz import window, actor
 
 # Enables/disables interactive visualization
 interactive = False
 
-ren = window.Renderer()
+scene = window.Scene()
 
 evals = tenfit.evals[13:43, 44:74, 28:29]
 evecs = tenfit.evecs[13:43, 44:74, 28:29]
@@ -236,12 +234,14 @@ contrast.
 cfa = RGB[13:43, 44:74, 28:29]
 cfa /= cfa.max()
 
-ren.add(actor.tensor_slicer(evals, evecs, scalar_colors=cfa, sphere=sphere, scale=0.3))
+scene.add(actor.tensor_slicer(evals, evecs, scalar_colors=cfa, sphere=sphere,
+                              scale=0.3))
 
 print('Saving illustration as tensor_ellipsoids.png')
-window.record(ren, n_frames=1, out_path='tensor_ellipsoids.png', size=(600, 600))
+window.record(scene, n_frames=1, out_path='tensor_ellipsoids.png',
+              size=(600, 600))
 if interactive:
-    window.show(ren)
+    window.show(scene)
 
 """
 .. figure:: tensor_ellipsoids.png
@@ -250,7 +250,7 @@ if interactive:
    Tensor Ellipsoids.
 """
 
-window.clear(ren)
+scene.clear()
 
 """
 Finally, we can visualize the tensor Orientation Distribution Functions
@@ -259,12 +259,13 @@ for the same area as we did with the ellipsoids.
 
 tensor_odfs = tenmodel.fit(data[20:50, 55:85, 38:39]).odf(sphere)
 
-odf_actor = actor.odf_slicer(tensor_odfs, sphere=sphere, scale=0.5, colormap=None)
-ren.add(odf_actor)
+odf_actor = actor.odf_slicer(tensor_odfs, sphere=sphere, scale=0.5,
+                             colormap=None)
+scene.add(odf_actor)
 print('Saving illustration as tensor_odfs.png')
-window.record(ren, n_frames=1, out_path='tensor_odfs.png', size=(600, 600))
+window.record(scene, n_frames=1, out_path='tensor_odfs.png', size=(600, 600))
 if interactive:
-    window.show(ren)
+    window.show(scene)
 
 """
 .. figure:: tensor_odfs.png
