@@ -21,12 +21,15 @@ streamline bundle.
 
 
 def get_streamlines():
-    from nibabel import trackvis as tv
-    from dipy.data import get_data
+    from dipy.data import get_fnames
+    from dipy.io.streamline import load_tractogram
+    from dipy.tracking.streamline import Streamlines
 
-    fname = get_data('fornix')
-    streams, hdr = tv.read(fname)
-    streamlines = [i[0] for i in streams]
+    fname = get_fnames('fornix')
+    fornix = load_tractogram(fname, 'same',
+                             bbox_valid_check=False).streamlines
+
+    streamlines = Streamlines(fornix)
     return streamlines
 
 """
@@ -167,14 +170,15 @@ for cluster, color in zip(clusters, colormap):
     colormap_full[cluster.indices] = color
 
 # Visualization
-ren = window.Renderer()
-window.clear(ren)
-ren.SetBackground(0, 0, 0)
-ren.add(actor.streamtube(streamlines, window.colors.white, opacity=0.05))
-ren.add(actor.point(centers[:, 0, :], colormap_full, point_radius=0.2))
-window.record(ren, n_frames=1, out_path='center_of_mass_feature.png', size=(600, 600))
+scene = window.Scene()
+scene.clear()
+scene.SetBackground(0, 0, 0)
+scene.add(actor.streamtube(streamlines, window.colors.white, opacity=0.05))
+scene.add(actor.point(centers[:, 0, :], colormap_full, point_radius=0.2))
+window.record(scene, n_frames=1, out_path='center_of_mass_feature.png',
+              size=(600, 600))
 if interactive:
-    window.show(ren)
+    window.show(scene)
 
 """
 .. figure:: center_of_mass_feature.png
@@ -221,14 +225,15 @@ for cluster, color in zip(clusters, colormap):
     colormap_full[cluster.indices] = color
 
 # Visualization
-ren = window.Renderer()
-window.clear(ren)
-ren.SetBackground(0, 0, 0)
-ren.add(actor.point(midpoints[:, 0, :], colormap_full, point_radius=0.2))
-ren.add(actor.streamtube(streamlines, window.colors.white, opacity=0.05))
-window.record(ren, n_frames=1, out_path='midpoint_feature.png', size=(600, 600))
+scene = window.Scene()
+scene.clear()
+scene.SetBackground(0, 0, 0)
+scene.add(actor.point(midpoints[:, 0, :], colormap_full, point_radius=0.2))
+scene.add(actor.streamtube(streamlines, window.colors.white, opacity=0.05))
+window.record(scene, n_frames=1, out_path='midpoint_feature.png',
+              size=(600, 600))
 if interactive:
-    window.show(ren)
+    window.show(scene)
 
 """
 .. figure:: midpoint_feature.png
@@ -270,13 +275,13 @@ for cluster, color in zip(clusters, colormap):
     colormap_full[cluster.indices] = color
 
 # Visualization
-ren = window.Renderer()
-window.clear(ren)
-ren.SetBackground(0, 0, 0)
-ren.add(actor.streamtube(streamlines, colormap_full))
-window.record(ren, out_path='arclength_feature.png', size=(600, 600))
+scene = window.Scene()
+scene.clear()
+scene.SetBackground(0, 0, 0)
+scene.add(actor.streamtube(streamlines, colormap_full))
+window.record(scene, out_path='arclength_feature.png', size=(600, 600))
 if interactive:
-    window.show(ren)
+    window.show(scene)
 
 """
 .. figure:: arclength_feature.png
@@ -322,13 +327,14 @@ for cluster, color in zip(clusters, colormap):
     colormap_full[cluster.indices] = color
 
 # Visualization
-ren = window.Renderer()
-window.clear(ren)
-ren.SetBackground(0, 0, 0)
-ren.add(actor.streamtube(streamlines, colormap_full))
-window.record(ren, out_path='vector_of_endpoints_feature.png', size=(600, 600))
+scene = window.Scene()
+scene.clear()
+scene.SetBackground(0, 0, 0)
+scene.add(actor.streamtube(streamlines, colormap_full))
+window.record(scene, out_path='vector_of_endpoints_feature.png',
+              size=(600, 600))
 if interactive:
-    window.show(ren)
+    window.show(scene)
 
 """
 .. figure:: vector_of_endpoints_feature.png
