@@ -6,7 +6,7 @@ Connectivity Matrices, ROI Intersections and Density Maps
 =========================================================
 
 This example is meant to be an introduction to some of the streamline tools
-available in dipy_. Some of the functions covered in this example are
+available in DIPY_. Some of the functions covered in this example are
 ``target``, ``connectivity_matrix`` and ``density_map``. ``target`` allows one
 to filter streamlines that either pass through or do not pass through some
 region of the brain, ``connectivity_matrix`` groups and counts streamlines
@@ -18,19 +18,30 @@ EuDX along with the CsaOdfModel to make some streamlines. Let's import the
 modules and download the data we'll be using.
 """
 
-from dipy.tracking.eudx import EuDX
-from dipy.reconst import peaks, shm
+import numpy as np
+from scipy.ndimage.morphology import binary_dilation
+
+from dipy.core.gradients import gradient_table
+from dipy.data import get_fnames
+from dipy.io.gradients import read_bvals_bvecs
+from dipy.io.image import load_nifti_data, load_nifti, save_nifti
+from dipy.direction import peaks
+from dipy.reconst import shm
 from dipy.tracking import utils
+from dipy.tracking.local_tracking import LocalTracking
+from dipy.tracking.stopping_criterion import BinaryStoppingCriterion
+from dipy.tracking.streamline import Streamlines
 
-from dipy.data import read_stanford_labels, fetch_stanford_t1, read_stanford_t1
 
-hardi_img, gtab, labels_img = read_stanford_labels()
-data = hardi_img.get_data()
-labels = labels_img.get_data()
+hardi_fname, hardi_bval_fname, hardi_bvec_fname = get_fnames('stanford_hardi')
+label_fname = get_fnames('stanford_labels')
+t1_fname = get_fnames('stanford_t1')
 
-fetch_stanford_t1()
-t1 = read_stanford_t1()
-t1_data = t1.get_data()
+data, affine, hardi_img = load_nifti(hardi_fname, return_img=True)
+labels = load_nifti_data(label_fname)
+t1_data = load_nifti_data(t1_fname)
+bvals, bvecs = read_bvals_bvecs(hardi_bval_fname, hardi_bvec_fname)
+gtab = gradient_table(bvals, bvecs)
 
 """
 We've loaded an image called ``labels_img`` which is a map of tissue types such
@@ -38,10 +49,11 @@ that every integer value in the array ``labels`` represents an anatomical
 structure or tissue type [#]_. For this example, the image was created so that
 white matter voxels have values of either 1 or 2. We'll use
 ``peaks_from_model`` to apply the ``CsaOdfModel`` to each white matter voxel
-and estimate fiber orientations which we can use for tracking.
+and estimate fiber orientations which we can use for tracking. We will also
+dilate this mask by 1 voxel to ensure streamlines reach the grey matter.
 """
 
-white_matter = (labels == 1) | (labels == 2)
+white_matter = binary_dilation((labels == 1) | (labels == 2))
 csamodel = shm.CsaOdfModel(gtab, 6)
 csapeaks = peaks.peaks_from_model(model=csamodel,
                                   data=data,
@@ -52,18 +64,18 @@ csapeaks = peaks.peaks_from_model(model=csamodel,
 
 """
 Now we can use EuDX to track all of the white matter. To keep things reasonably
-fast we use ``density=2`` which will result in 8 seeds per voxel. We'll set
-``a_low`` (the parameter which determines the threshold of FA/QA under which
-tracking stops) to be very low because we've already applied a white matter
-mask.
+fast we use ``density=1`` which will result in 1 seeds per voxel. The stopping
+criterion, determining when the tracking stops, is set to stop when the
+tracking exit the white matter.
 """
 
-seeds = utils.seeds_from_mask(white_matter, density=2)
-streamline_generator = EuDX(csapeaks.peak_values, csapeaks.peak_indices,
-                            odf_vertices=peaks.default_sphere.vertices,
-                            a_low=.05, step_sz=.5, seeds=seeds)
-affine = streamline_generator.affine
-streamlines = list(streamline_generator)
+affine = np.eye(4)
+seeds = utils.seeds_from_mask(white_matter, affine, density=1)
+stopping_criterion = BinaryStoppingCriterion(white_matter)
+
+streamline_generator = LocalTracking(csapeaks, stopping_criterion, seeds,
+                                     affine=affine, step_size=0.5)
+streamlines = Streamlines(streamline_generator)
 
 """
 The first of the tracking utilities we'll cover here is ``target``. This
@@ -80,48 +92,55 @@ with the ROI and those that don't.
 """
 
 cc_slice = labels == 2
-cc_streamlines = utils.target(streamlines, cc_slice, affine=affine)
-cc_streamlines = list(cc_streamlines)
+cc_streamlines = utils.target(streamlines, affine, cc_slice)
+cc_streamlines = Streamlines(cc_streamlines)
 
-other_streamlines = utils.target(streamlines, cc_slice, affine=affine,
+other_streamlines = utils.target(streamlines, affine, cc_slice,
                                  include=False)
-other_streamlines = list(other_streamlines)
+other_streamlines = Streamlines(other_streamlines)
 assert len(other_streamlines) + len(cc_streamlines) == len(streamlines)
 
 """
-We can use some of dipy_'s visualization tools to display the ROI we targeted
+We can use some of DIPY_'s visualization tools to display the ROI we targeted
 above and all the streamlines that pass though that ROI. The ROI is the yellow
 region near the center of the axial image.
 """
 
-from dipy.viz import fvtk
-from dipy.viz.colormap import line_colors
+from dipy.viz import window, actor, colormap as cmap
+
+# Enables/disables interactive visualization
+interactive = False
 
 # Make display objects
-color = line_colors(cc_streamlines)
-cc_streamlines_actor = fvtk.line(cc_streamlines, line_colors(cc_streamlines))
-cc_ROI_actor = fvtk.contour(cc_slice, levels=[1], colors=[(1., 1., 0.)],
-                            opacities=[1.])
+color = cmap.line_colors(cc_streamlines)
+cc_streamlines_actor = actor.line(cc_streamlines,
+                                  cmap.line_colors(cc_streamlines))
+cc_ROI_actor = actor.contour_from_roi(cc_slice, color=(1., 1., 0.),
+                                      opacity=0.5)
 
-vol_actor = fvtk.slicer(t1_data)
+vol_actor = actor.slicer(t1_data)
 
-vol_actor.display(40, None, None)
+vol_actor.display(x=40)
 vol_actor2 = vol_actor.copy()
-vol_actor2.display(None, None, 35)
+vol_actor2.display(z=35)
 
 # Add display objects to canvas
-r = fvtk.ren()
-fvtk.add(r, vol_actor)
-fvtk.add(r, vol_actor2)
-fvtk.add(r, cc_streamlines_actor)
-fvtk.add(r, cc_ROI_actor)
+scene = window.Scene()
+scene.add(vol_actor)
+scene.add(vol_actor2)
+scene.add(cc_streamlines_actor)
+scene.add(cc_ROI_actor)
 
 # Save figures
-fvtk.record(r, n_frames=1, out_path='corpuscallosum_axial.png',
-            size=(800, 800))
-fvtk.camera(r, [-1, 0, 0], [0, 0, 0], viewup=[0, 0, 1])
-fvtk.record(r, n_frames=1, out_path='corpuscallosum_sagittal.png',
-            size=(800, 800))
+window.record(scene, n_frames=1, out_path='corpuscallosum_axial.png',
+              size=(800, 800))
+if interactive:
+    window.show(scene)
+scene.set_camera(position=[-1, 0, 0], focal_point=[0, 0, 0], view_up=[0, 0, 1])
+window.record(scene, n_frames=1, out_path='corpuscallosum_sagittal.png',
+              size=(800, 800))
+if interactive:
+    window.show(scene)
 
 """
 .. figure:: corpuscallosum_axial.png
@@ -146,7 +165,8 @@ by their endpoints. Notice that this function only considers the endpoints of
 each streamline.
 """
 
-M, grouping = utils.connectivity_matrix(cc_streamlines, labels, affine=affine,
+M, grouping = utils.connectivity_matrix(cc_streamlines, affine,
+                                        labels.astype(np.uint8),
                                         return_mapping=True,
                                         mapping_as_streamlines=True)
 M[:3, :] = 0
@@ -168,6 +188,7 @@ scale to make small values in the matrix easier to see.
 
 import numpy as np
 import matplotlib.pyplot as plt
+
 plt.imshow(np.log1p(M), interpolation='nearest')
 plt.savefig("connectivity.png")
 
@@ -201,7 +222,7 @@ left and right superior frontal gyrus.
 
 lr_superiorfrontal_track = grouping[11, 54]
 shape = labels.shape
-dm = utils.density_map(lr_superiorfrontal_track, shape, affine=affine)
+dm = utils.density_map(lr_superiorfrontal_track, affine, shape)
 
 """
 Let's save this density map and the streamlines so that they can be
@@ -209,76 +230,32 @@ visualized together. In order to save the streamlines in a ".trk" file we'll
 need to move them to "trackvis space", or the representation of streamlines
 specified by the trackvis Track File format.
 
-To do that, we will use tools available in `nibabel <http://nipy.org/nibabel>`_)
 """
 
-import nibabel as nib
+from dipy.io.stateful_tractogram import Space, StatefulTractogram
+from dipy.io.streamline import save_trk
 
 # Save density map
-dm_img = nib.Nifti1Image(dm.astype("int16"), hardi_img.affine)
-dm_img.to_filename("lr-superiorfrontal-dm.nii.gz")
+save_nifti("lr-superiorfrontal-dm.nii.gz", dm.astype("int16"), affine)
 
-# Make a trackvis header so we can save streamlines
-voxel_size = labels_img.header.get_zooms()
-trackvis_header = nib.trackvis.empty_header()
-trackvis_header['voxel_size'] = voxel_size
-trackvis_header['dim'] = shape
-trackvis_header['voxel_order'] = "RAS"
-
-# Move streamlines to "trackvis space"
-trackvis_point_space = utils.affine_for_trackvis(voxel_size)
-lr_sf_trk = utils.move_streamlines(lr_superiorfrontal_track,
-                                   trackvis_point_space, input_space=affine)
-lr_sf_trk = list(lr_sf_trk)
+lr_sf_trk = Streamlines(lr_superiorfrontal_track)
 
 # Save streamlines
-for_save = [(sl, None, None) for sl in lr_sf_trk]
-nib.trackvis.write("lr-superiorfrontal.trk", for_save, trackvis_header)
+sft = StatefulTractogram(lr_sf_trk, hardi_img, Space.VOX)
+save_trk(sft, "lr-superiorfrontal.trk")
 
-"""
-Let's take a moment here to consider the representation of streamlines used in
-DIPY. Streamlines are a path though the 3D space of an image represented by a
-set of points. For these points to have a meaningful interpretation, these
-points must be given in a known coordinate system. The ``affine`` attribute of
-the ``streamline_generator`` object specifies the coordinate system of the
-points with respect to the voxel indices of the input data.
-``trackvis_point_space`` specifies the trackvis coordinate system with respect
-to the same indices. The ``move_streamlines`` function returns a new set of
-streamlines from an existing set of streamlines in the target space. The
-target space and the input space must be specified as affine transformations
-with respect to the same reference [#]_. If no input space is given, the input
-space will be the same as the current representation of the streamlines, in
-other words the input space is assumed to be ``np.eye(4)``, the 4-by-4 identity
-matrix.
-
-All of the functions above that allow streamlines to interact with volumes take
-an affine argument. This argument allows these functions to work with
-streamlines regardless of their coordinate system. For example even though we
-moved our streamlines to "trackvis space", we can still compute the density map
-as long as we specify the right coordinate system.
-"""
-
-dm_trackvis = utils.density_map(lr_sf_trk, shape, affine=trackvis_point_space)
-assert np.all(dm == dm_trackvis)
-
-"""
-This means that streamlines can interact with any image volume, for example a
-high resolution structural image, as long as one can register that image to
-the diffusion images and calculate the coordinate system with respect to that
-image.
-"""
 """
 .. rubric:: Footnotes
 
 .. [#] The image `aparc-reduced.nii.gz`, which we load as ``labels_img``, is a
-    modified version of label map `aparc+aseg.mgz` created by `FreeSurfer
-    <https://surfer.nmr.mgh.harvard.edu/>`_. The corpus callosum region is a
-    combination of the FreeSurfer labels 251-255. The remaining FreeSurfer
-    labels were re-mapped and reduced so that they lie between 0 and 88. To
-    see the FreeSurfer region, label and name, represented by each value see
-   `label_info.txt` in `~/.dipy/stanford_hardi`.
+       modified version of label map `aparc+aseg.mgz` created by `FreeSurfer
+       <https://surfer.nmr.mgh.harvard.edu/>`_. The corpus callosum region is a
+       combination of the FreeSurfer labels 251-255. The remaining FreeSurfer
+       labels were re-mapped and reduced so that they lie between 0 and 88. To
+       see the FreeSurfer region, label and name, represented by each value see
+       `label_info.txt` in `~/.dipy/stanford_hardi`.
 .. [#] An affine transformation is a mapping between two coordinate systems
-    that can represent scaling, rotation, sheer, translation and reflection.
-    Affine transformations are often represented using a 4x4 matrix where the
-    last row of the matrix is ``[0, 0, 0, 1]``.
+       that can represent scaling, rotation, sheer, translation and reflection.
+       Affine transformations are often represented using a 4x4 matrix where
+       the last row of the matrix is ``[0, 0, 0, 1]``.
 """
