@@ -4,12 +4,12 @@
 Tissue Classification of a T1-weighted Structural Image
 =======================================================
 
-This example explains how to segment a T1-weighted structural image by using a 
-Bayesian formulation. The observation model (likelihood term) is defined as a 
-Gaussian distribution and a Markov Random Field (MRF) is used to model the a 
-priori probability of the context-dependent patterns of the different tissue 
-types of the brain. Expectation Maximization and Iterated Conditional 
-Modes are used to find the optimal solution. Similar algorithms have been 
+This example explains how to segment a T1-weighted structural image by using 
+Bayesian formulation. The observation model (likelihood term) is defined as a
+Gaussian distribution and a Markov Random Field (MRF) is used to model the 
+a priori probability of context-dependent patterns of different tissue
+types of the brain. Expectation Maximization and Iterated Conditional
+Modes are used to find the optimal solution. Similar algorithms have been
 proposed by Zhang et al. [Zhang2001]_ and Avants et al. [Avants2011]_ available
 in FAST-FSL and ANTS-atropos, respectively.
 
@@ -19,20 +19,21 @@ and bias field corrected.
 
 import numpy as np
 import matplotlib.pyplot as plt
-from dipy.data import fetch_tissue_data, read_tissue_data
+from dipy.data import get_fnames
+from dipy.io.image import load_nifti_data
 from dipy.segment.tissue import TissueClassifierHMRF
+import time
 
 """
 First we fetch the T1 volume from the Syn dataset and determine its shape.
 """
 
-fetch_tissue_data()
-t1_img = read_tissue_data()
-t1 = t1_img.get_data()
+t1_fname, _, _ = get_fnames('tissue_data')
+t1 = load_nifti_data(t1_fname)
 print('t1.shape (%d, %d, %d)' % t1.shape)
 
 """
-We have fetched the T1 volume. Now we will look at the axial and the coronal
+We have fetched the T1 volume. Now we will look at the axial and coronal
 slices of the image.
 """
 
@@ -64,21 +65,19 @@ nclass = 3
 
 """
 Then, the smoothness factor of the segmentation. Good performance is achieved
-with values between 0 and 0.5.
+with values between 0 and 0.5. 
 """
 
 beta = 0.1
 
 """
 We could also set the number of iterations. By default this parameter is set to
-100 iterations, but most of the times the the ICM (Iterated Conditional Modes)
+100 iterations, but most of the times the ICM (Iterated Conditional Modes)
 loop will converge before reaching the 100th iteration.
 After setting the necessary parameters we can now call an instance of the class
 "TissueClassifierHMRF" and its method called "classify" and input the
 parameters defined above to perform the segmentation task.
 """
-
-import time
 t0 = time.time()
 
 hmrf = TissueClassifierHMRF()
